--[[----------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------
--
-- TOOL NAME: GT16-Colors
-- VERSIÓN: 1.1 (for R3.1)
-- COMPATIBILITY: Windows, Mac, Linux (32/64bit)
-- AUTHOR: ulneiz (Spain)
-- DATE: Summer 2016
--
--------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------]]--

--------------------------------------------------------------------------------
-- INITIALS
--------------------------------------------------------------------------------
dialog = nil -- Placeholder for the dialog
vb = renoise.ViewBuilder() -- ViewBuilder for show_dialog() function & others


class 'RenoiseScriptingTool' ( renoise.Document.DocumentNode )
  function RenoiseScriptingTool:__init()    
    renoise.Document.DocumentNode.__init(self) 
    self:add_property( 'Name' , 'Untitled Tool' )
  self:add_property( 'Version', '1.1')
    self:add_property( 'Id' , 'Unknown Id' )
  end

manifest = RenoiseScriptingTool()
ok,err = manifest:load_from( 'manifest.xml' )
tool_name = manifest:property( 'Name' ).value
tool_id = manifest:property( 'Id' ).value
tool_version = manifest:property('Version').value


--------------------------------------------------------------------------------
-- CONSTANTS
--------------------------------------------------------------------------------
TAB_COM = 1
TAB_MGR = 2
TAB_GRP = 3
TAB_SGR = 4
TAB_TRK = 5
TAB_CMB = 6

SGRTAB_SGR = 1
SGRTAB_OCT = 2

SUBTAB_MGR = 1
SUBTAB_GRP = 2
SUBTAB_SGR = 3
SUBTAB_TRK = 4

HLPTAB_CLS = 1
HLPTAB_HLP = 2
HLPTAB_ABO = 3
HLPTAB_TLS = 4

TLSTAB_01 = 1
TLSTAB_02 = 2
TLSTAB_03 = 3
TLSTAB_04 = 4
TLSTAB_05 = 5
TLSTAB_06 = 6
TLSTAB_07 = 7
TLSTAB_08 = 8
TLSTAB_09 = 9
TLSTAB_10 = 10

F , T = false , true

Aqua_zero       = { 0x2A,0xAA,0x9D }  Aqua_one       = { 0x1A,0x9A,0x8D }  Aqua_two       = { 0x00,0x5A,0x4D }
Black_zero      = { 0x00,0x00,0x00 }  Black_one      = { 0x54,0x54,0x54 }  Black_two      = { 0x20,0x20,0x20 }
Blue_zero       = { 0x00,0x60,0xFF }  Blue_one       = { 0x00,0x44,0xFF }  Blue_two       = { 0x2A,0x3C,0xAA }
Brown_zero      = { 0xA9,0x5D,0x10 }  Brown_one      = { 0x99,0x4D,0x00 }  Brown_two      = { 0x40,0x00,0x00 }
Gold_zero       = { 0xFF,0xB5,0x23 }  Gold_one       = { 0xEF,0xA5,0x13 }  Gold_two       = { 0xAF,0x5B,0x00 }
Gray_zero       = { 0x80,0x80,0x80 }  Gray_one       = { 0x70,0x70,0x70 }  Gray_two       = { 0x40,0x40,0x40 }
Green_zero      = { 0x00,0xFF,0x2A }  Green_one      = { 0x00,0x99,0x19 }  Green_two      = { 0x00,0x40,0x19 }
Orange_zero     = { 0xFF,0x80,0x00 }  Orange_one     = { 0xEE,0x70,0x00 }  Orange_two     = { 0x90,0x45,0x00 }
Pale_Pink_zero  = { 0xF4,0xA1,0xD9 }  Pale_Pink_one  = { 0xE4,0xB1,0xC9 }  Pale_Pink_two  = { 0xA4,0x61,0x79 }
Pink_zero       = { 0xFF,0x00,0xAA }  Pink_one       = { 0xE0,0x00,0x90 }  Pink_two       = { 0x5D,0x00,0x27 }
Pistachio_zero  = { 0x80,0xFF,0x95 }  Pistachio_one  = { 0x70,0xEF,0x85 }  Pistachio_two  = { 0x20,0x9F,0x35 }
Red_zero        = { 0xFF,0x00,0x00 }  Red_one        = { 0xCC,0x00,0x00 }  Red_two        = { 0x60,0x00,0x00 }
Sky_Blue_zero   = { 0x00,0xCC,0xFF }  Sky_Blue_one   = { 0x00,0xDD,0xEE }  Sky_Blue_two   = { 0x00,0x89,0x9A }
Violet_zero     = { 0x8C,0x00,0xFF }  Violet_one     = { 0x81,0x00,0xEB }  Violet_two     = { 0x4C,0x00,0x90 }
White_zero      = { 0xFF,0xFF,0xFF }  White_one      = { 0xF1,0xF1,0xF1 }  White_two      = { 0x60,0x60,0x60 }
Yellow_zero     = { 0xFF,0xFF,0x00 }  Yellow_one     = { 0xD1,0xD1,0x00 }  Yellow_two     = { 0x61,0x61,0x00 }


--------------------------------------------------------------------------------
-- INCLUDES
--------------------------------------------------------------------------------
require ("tools/tool_01")
require ("tools/tool_02")
-- require ("tools/tool_03")
-- require ("tools/tool_04")
-- require ("tools/tool_05")
-- require ("tools/tool_06")
-- require ("tools/tool_07")
-- require ("tools/tool_08")
-- require ("tools/tool_09")
-- require ("tools/tool_10")


--------------------------------------------------------------------------------
-- UTILITY FUNCTIONS
--------------------------------------------------------------------------------
function LOG(...) print (...) end -- log print

--------------------------------------------------------------------------------
-- TABS NAVEGATION
--------------------------------------------------------------------------------

-- TAB Control------------------
-- show/update the indicated tab
function show_tab( idx )
  LOG( 'show_tab()' , idx )
  vb.views.tab_com.visible = ( idx == TAB_COM ) and true or false
  vb.views.tab_mgr.visible = ( idx == TAB_MGR ) and true or false
  vb.views.tab_grp.visible = ( idx == TAB_GRP ) and true or false
  vb.views.tab_sgr.visible = ( idx == TAB_SGR ) and true or false
  vb.views.tab_trk.visible = ( idx == TAB_TRK ) and true or false
  vb.views.tab_cmb.visible = ( idx == TAB_CMB ) and true or false
end

-- next/previous tab
function show_next_tab()
  local new_tab = visible_tab
  if ( visible_tab == TAB_CMB ) then
    new_tab = TAB_COM
    else
    new_tab = new_tab + 1
  end
  vb.views.main_switch.value = new_tab
end

function show_previous_tab()
  local new_tab = visible_tab
  if ( visible_tab == TAB_COM ) then
    new_tab = TAB_CMB
    else
    new_tab = new_tab - 1
  end
  vb.views.main_switch.value = new_tab
end

-- force update of current tab
function update_tab()
  local tab_idx = visible_tab
  visible_tab = 0
  show_tab( tab_idx )
end

-- SGRTAB Control------------------
-- show/update the indicated tab
function show_sgrtab( idx )
  LOG( 'show_sgrtab()' , idx )
  vb.views.sgrtab_sgr.visible = ( idx == SGRTAB_SGR ) and true or false
  vb.views.sgrtab_oct.visible = ( idx == SGRTAB_OCT ) and true or false
end

-- next/previous sgrtab
function show_next_sgrtab()
  local new_sgrtab = visible_sgrtab
  if ( visible_sgrtab == SGRTAB_OCT ) then
    new_sgrtab = SGRTAB_SGR
    else
    new_sgrtab = new_sgrtab + 1
  end
  vb.views.main_switch.value = new_sgrtab
end

function show_previous_sgrtab()
  local new_sgrtab = visible_sgrtab
  if ( visible_sgrtab == SGRTAB_SGR ) then
    new_sgrtab = SGRTAB_OCT
    else
    new_sgrtab = new_sgrtab - 1
  end
  vb.views.main_switch.value = new_sgrtab
end

-- force update of current sgrtab
function update_sgrtab()
  local sgrtab_idx = visible_sgrtab
  visible_sgrtab = 0
  show_sgrtab( sgrtab_idx )
end



-- SUBTAB Control------------------
-- show/update the indicated subtab
function show_subtab( idx )
  LOG( 'show_subtab()' , idx )
  vb.views.subtab_mgr.visible = ( idx == SUBTAB_MGR ) and true or false
  vb.views.subtab_grp.visible = ( idx == SUBTAB_GRP ) and true or false
  vb.views.subtab_sgr.visible = ( idx == SUBTAB_SGR ) and true or false
  vb.views.subtab_trk.visible = ( idx == SUBTAB_TRK ) and true or false
end 

-- next/previous subtab
function show_next_subtab()
  local new_subtab = visible_subtab
  if ( visible_subtab == SUBTAB_TRK ) then
    new_subtab = SUBTAB_MGR
  else
    new_subtab = new_subtab + 1
  end
  vb.views.submain_switch.value = new_subtab
end

function show_previous_subtab()
  local new_subtab = visible_subtab
  if ( visible_subtab == SUBTAB_MGR ) then
    new_subtab = SUBTAB_TRK
    else
    new_subtab = new_subtab - 1
  end
  vb.views.submain_switch.value = new_subtab
end

-- force update of current subtab
function update_subtab()
  local subtab_idx = visible_subtab
  visible_subtab = 0
  show_subtab( subtab_idx )
end


-- HLPTAP Control------------------
-- show/update the indicated subtab
function show_hlptab( idx )
  LOG( 'show_hlptab()' , idx )
  vb.views.hlptab_cls.visible = ( idx == HLPTAB_CLS ) and true or false
  vb.views.hlptab_hlp.visible = ( idx == HLPTAB_HLP ) and true or false
  vb.views.hlptab_abo.visible = ( idx == HLPTAB_ABO ) and true or false
  vb.views.hlptab_tls.visible = ( idx == HLPTAB_TLS ) and true or false
end 

-- next/previous hlptab
function show_next_hlptab()
  local new_hlptab = visible_hlptab
  if ( visible_hlptab == HLPTAB_TLS ) then
    new_hlptab = HLPTAB_CLS
    else
    new_hlptab = new_hlptab + 1
  end
  vb.views.help_switch.value = new_hlptab
end

function show_previous_hlptab()
  local new_hlptab = visible_hlptab
  if ( visible_hlptab == HLPTAB_CLS ) then
    new_hlptab = HLPTAB_TLS
    else
    new_hlptab = new_hlptab - 1
  end
  vb.views.help_switch.value = new_hlptab
end

-- force update of current hlptab
function update_hlptab()
  local hlptab_idx = visible_hlptab
  visible_hlptab = 0
  show_hlptab( hlptab_idx )
end


-- TLSTAB Control------------------
-- show/update the indicated tlstab
function show_tlstab( idx )
  LOG( 'show_tlstab()' , idx )
  vb.views.tlstab_01.visible = ( idx == TLSTAB_01 ) and true or false
  vb.views.tlstab_02.visible = ( idx == TLSTAB_02 ) and true or false
  vb.views.tlstab_03.visible = ( idx == TLSTAB_03 ) and true or false
  vb.views.tlstab_04.visible = ( idx == TLSTAB_04 ) and true or false
  vb.views.tlstab_05.visible = ( idx == TLSTAB_05 ) and true or false
  vb.views.tlstab_06.visible = ( idx == TLSTAB_06 ) and true or false
  vb.views.tlstab_07.visible = ( idx == TLSTAB_07 ) and true or false
  vb.views.tlstab_08.visible = ( idx == TLSTAB_08 ) and true or false
  vb.views.tlstab_09.visible = ( idx == TLSTAB_09 ) and true or false
  vb.views.tlstab_10.visible = ( idx == TLSTAB_10 ) and true or false
end 

-- next/previous tlstab
function show_next_tlstab()
  local new_tlstab = visible_tlstab
  if ( visible_tlstab == TLSTAB_10 ) then
    new_tlstab = TLSTAB_01
  else
    new_tlstab = new_tlstab + 1
  end
  vb.views.tools_switch.value = new_tlstab
end

function show_previous_tlstab()
  local new_tlstab = visible_tlstab
  if ( visible_tlstab == TLSTAB_01 ) then
    new_tlstab = TLSTAB_10
  else
    new_tlstab = new_tlstab - 1
  end
  vb.views.tools_switch.value = new_tlstab
end

-- force update of current tlstab
function update_tlstab()
  local tlstab_idx = visible_tlstab
  visible_tlstab = 0
  show_tlstab( tlstab_idx )
end


--------------------------------------------------------------------------------
-- NAVIGATION BARS
--------------------------------------------------------------------------------
function show_cbox_bars( idx )
  LOG( 'show_cbox_bars()' , idx )
  vb.views.cbox_bars_t.visible = ( idx == true )
  vb.views.cbox_bars_f.visible = ( idx == false )
end

checkbox_bars = vb:checkbox { id = 'cbox_bars', tooltip = 'Show/Hide the Bars bellow', notifier = function(new_idx) show_cbox_bars(new_idx) end }



--------------------------------------------------------------------------------
-- TRACKS COLORS, OCTAVES COLORS
--------------------------------------------------------------------------------
function track_colors( C , N )
  local ONE = _G[ C..'_one' ] -- G_C_one
  local TWO = _G[ C..'_two' ] -- G_C_two
  local track = {}
    track.a1    = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }
    track.a2    = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }
    track.one   = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '01 '.. C ..' Track' }
    track.two   = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '02 '.. C ..' Track' }
    track.three = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '03 '.. C ..' Track' }
    track.four  = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '04 '.. C ..' Track' }
    track.five  = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '05 '.. C ..' Track' }
    track.six   = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '06 '.. C ..' Track' }
    track.seven = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '07 '.. C ..' Track' }
    track.eight = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '08 '.. C ..' Track' }


      if ( N == 'a1' )     then return { track.a1 }
  elseif ( N == 'a2' )     then return { track.a2 }
  elseif ( N == 'one' )    then return { track.one }
  elseif ( N == 'two' )    then return { track.one , track.two }
  elseif ( N == 'three' )  then return { track.one , track.two , track.three }
  elseif ( N == 'four' )   then return { track.one , track.two , track.three , track.four }
  elseif ( N == 'five' )   then return { track.one , track.two , track.three , track.four , track.five }
  elseif ( N == 'six' )    then return { track.one , track.two , track.three , track.four , track.five , track.six }
  elseif ( N == 'seven' )  then return { track.one , track.two , track.three , track.four , track.five , track.six , track.seven }
  elseif ( N == 'eight' )  then return { track.one , track.two , track.three , track.four , track.five , track.six , track.seven , track.eight }
  end
end

function octave_colors( C , N )
  local ONE = _G[ C..'_one' ] -- G_C_one
  local TWO = _G[ C..'_two' ] -- G_C_two
  local octave = {}
    octave.zero  = { color = ONE , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '0 Octave '.. C ..' Track' }
  octave.one   = { color = TWO , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '1 Octave '.. C ..' Track' }
    octave.two   = { color = ONE , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '2 Octave '.. C ..' Track' }
    octave.three = { color = TWO , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '3 Octave '.. C ..' Track' }
    octave.four  = { color = ONE , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '4 Octave '.. C ..' Track' }
    octave.five  = { color = TWO , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '5 Octave '.. C ..' Track' }
    octave.six   = { color = ONE , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '6 Octave '.. C ..' Track' }
    octave.seven = { color = TWO , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '7 Octave '.. C ..' Track' }
    octave.eight = { color = ONE , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '8 Octave '.. C ..' Track' }
  octave.nine  = { color = TWO , color_blend = 10 , volume_column_visible = T , delay_column_visible = T , collapsed = T , name = '9 Octave '.. C ..' Track' }

    if ( N == 'zero_nine' )   then return { octave.zero , octave.one , octave.two , octave.three , octave.four , octave.five , octave.six , octave.seven , octave.eight , octave.nine }
  elseif ( N == 'zero_three' )  then return { octave.zero , octave.one , octave.two , octave.three }
  elseif ( N == 'four_six' )    then return { octave.four , octave.five , octave.six }
  elseif ( N == 'seven_nine' )  then return { octave.seven , octave.eight , octave.nine }
  elseif ( N == 'three_seven' ) then return { octave.three , octave.four , octave.five , octave.six , octave.seven }
  end
end

--------------------------------------------------------------------------------
-- OCTAVE SUBGROUPS COLORS
--------------------------------------------------------------------------------
octave_settings = {

  -- Octave SubGroups AQUA Color aq
    oct_zero_nine_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Aqua SubGroup' , tracks = octave_colors ( 'Aqua' , 'zero_nine' ) } ,
   oct_zero_three_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Aqua SubGroup' , tracks = octave_colors ( 'Aqua' , 'zero_three' ) } ,
     oct_four_six_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Aqua SubGroup' , tracks = octave_colors ( 'Aqua' , 'four_six' ) } ,
   oct_seven_nine_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Aqua SubGroup' , tracks = octave_colors ( 'Aqua' , 'seven_nine' ) } ,
  oct_three_seven_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Aqua SubGroup' , tracks = octave_colors ( 'Aqua' , 'three_seven' ) } ,
  
    -- Octave SubGroups BLACK Color bk
    oct_zero_nine_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Black SubGroup' , tracks = octave_colors ( 'Black' , 'zero_nine' ) } ,
   oct_zero_three_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Black SubGroup' , tracks = octave_colors ( 'Black' , 'zero_three' ) } ,
     oct_four_six_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Black SubGroup' , tracks = octave_colors ( 'Black' , 'four_six' ) } ,
   oct_seven_nine_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Black SubGroup' , tracks = octave_colors ( 'Black' , 'seven_nine' ) } ,
  oct_three_seven_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Black SubGroup' , tracks = octave_colors ( 'Black' , 'three_seven' ) } ,
  
    -- Octave SubGroups BLUE Color bl
    oct_zero_nine_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'zero_nine' ) } ,
   oct_zero_three_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'zero_three' ) } ,
     oct_four_six_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'four_six' ) } ,
   oct_seven_nine_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'seven_nine' ) } ,
  oct_three_seven_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'three_seven' ) } ,
  
    -- Octave SubGroups BROWN Color br
    oct_zero_nine_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Brown SubGroup' , tracks = octave_colors ( 'Brown' , 'zero_nine' ) } ,
   oct_zero_three_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Brown SubGroup' , tracks = octave_colors ( 'Brown' , 'zero_three' ) } ,
     oct_four_six_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Brown SubGroup' , tracks = octave_colors ( 'Brown' , 'four_six' ) } ,
   oct_seven_nine_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Brown SubGroup' , tracks = octave_colors ( 'Brown' , 'seven_nine' ) } ,
  oct_three_seven_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Brown SubGroup' , tracks = octave_colors ( 'Brown' , 'three_seven' ) } ,
  
    -- Octave SubGroups GOLD Color gl
    oct_zero_nine_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Gold SubGroup' , tracks = octave_colors ( 'Gold' , 'zero_nine' ) } ,
   oct_zero_three_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Gold SubGroup' , tracks = octave_colors ( 'Gold' , 'zero_three' ) } ,
     oct_four_six_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Gold SubGroup' , tracks = octave_colors ( 'Gold' , 'four_six' ) } ,
   oct_seven_nine_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Gold SubGroup' , tracks = octave_colors ( 'Gold' , 'seven_nine' ) } ,
  oct_three_seven_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Gold SubGroup' , tracks = octave_colors ( 'Gold' , 'three_seven' ) } ,
  
    -- Octave SubGroups GRAY Color gy
    oct_zero_nine_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Gray SubGroup' , tracks = octave_colors ( 'Gray' , 'zero_nine' ) } ,
   oct_zero_three_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Gray SubGroup' , tracks = octave_colors ( 'Gray' , 'zero_three' ) } ,
     oct_four_six_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Gray SubGroup' , tracks = octave_colors ( 'Gray' , 'four_six' ) } ,
   oct_seven_nine_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Gray SubGroup' , tracks = octave_colors ( 'Gray' , 'seven_nine' ) } ,
  oct_three_seven_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Gray SubGroup' , tracks = octave_colors ( 'Gray' , 'three_seven' ) } ,
  
    -- Octave SubGroups GREEN Color gr
    oct_zero_nine_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Green SubGroup' , tracks = octave_colors ( 'Green' , 'zero_nine' ) } ,
   oct_zero_three_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Green SubGroup' , tracks = octave_colors ( 'Green' , 'zero_three' ) } ,
     oct_four_six_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Green SubGroup' , tracks = octave_colors ( 'Green' , 'four_six' ) } ,
   oct_seven_nine_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Green SubGroup' , tracks = octave_colors ( 'Green' , 'seven_nine' ) } ,
  oct_three_seven_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Green SubGroup' , tracks = octave_colors ( 'Green' , 'three_seven' ) } ,
  
    -- Octave SubGroups ORGANGE Color or
    oct_zero_nine_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Orange SubGroup' , tracks = octave_colors ( 'Orange' , 'zero_nine' ) } ,
   oct_zero_three_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Orange SubGroup' , tracks = octave_colors ( 'Orange' , 'zero_three' ) } ,
     oct_four_six_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Orange SubGroup' , tracks = octave_colors ( 'Orange' , 'four_six' ) } ,
   oct_seven_nine_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Orange SubGroup' , tracks = octave_colors ( 'Orange' , 'seven_nine' ) } ,
  oct_three_seven_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Orange SubGroup' , tracks = octave_colors ( 'Orange' , 'three_seven' ) } ,
  
    -- Octave SubGroups PALE PINK Color pl
    oct_zero_nine_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Pale_Pink SubGroup' , tracks = octave_colors ( 'Pale_Pink' , 'zero_nine' ) } ,
   oct_zero_three_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Pale_Pink SubGroup' , tracks = octave_colors ( 'Pale_Pink' , 'zero_three' ) } ,
     oct_four_six_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Pale_Pink SubGroup' , tracks = octave_colors ( 'Pale_Pink' , 'four_six' ) } ,
   oct_seven_nine_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Pale_Pink SubGroup' , tracks = octave_colors ( 'Pale_Pink' , 'seven_nine' ) } ,
  oct_three_seven_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Pale_Pink SubGroup' , tracks = octave_colors ( 'Pale_Pink' , 'three_seven' ) } ,
  
    -- Octave SubGroups PINK Color pn
    oct_zero_nine_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Pink SubGroup' , tracks = octave_colors ( 'Pink' , 'zero_nine' ) } ,
   oct_zero_three_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Pink SubGroup' , tracks = octave_colors ( 'Pink' , 'zero_three' ) } ,
     oct_four_six_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Pink SubGroup' , tracks = octave_colors ( 'Pink' , 'four_six' ) } ,
   oct_seven_nine_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Pink SubGroup' , tracks = octave_colors ( 'Pink' , 'seven_nine' ) } ,
  oct_three_seven_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Pink SubGroup' , tracks = octave_colors ( 'Pink' , 'three_seven' ) } ,
  
    -- Octave SubGroups PISTACHIO Color ps
    oct_zero_nine_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Pistachio SubGroup' , tracks = octave_colors ( 'Pistachio' , 'zero_nine' ) } ,
   oct_zero_three_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Pistachio SubGroup' , tracks = octave_colors ( 'Pistachio' , 'zero_three' ) } ,
     oct_four_six_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Pistachio SubGroup' , tracks = octave_colors ( 'Pistachio' , 'four_six' ) } ,
   oct_seven_nine_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Pistachio SubGroup' , tracks = octave_colors ( 'Pistachio' , 'seven_nine' ) } ,
  oct_three_seven_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Pistachio SubGroup' , tracks = octave_colors ( 'Pistachio' , 'three_seven' ) } ,
  
    -- Octave SubGroups RED Color rd
    oct_zero_nine_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Red SubGroup' , tracks = octave_colors ( 'Red' , 'zero_nine' ) } ,
   oct_zero_three_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Red SubGroup' , tracks = octave_colors ( 'Red' , 'zero_three' ) } ,
     oct_four_six_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Red SubGroup' , tracks = octave_colors ( 'Red' , 'four_six' ) } ,
   oct_seven_nine_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Red SubGroup' , tracks = octave_colors ( 'Red' , 'seven_nine' ) } ,
  oct_three_seven_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Red SubGroup' , tracks = octave_colors ( 'Red' , 'three_seven' ) } ,
  
    -- Octave SubGroups SKY BLUE Color sk
    oct_zero_nine_sky = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'zero_nine' ) } ,
   oct_zero_three_sky = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'zero_three' ) } ,
     oct_four_six_sky = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'four_six' ) } ,
   oct_seven_nine_sky = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'seven_nine' ) } ,
  oct_three_seven_sky = { color = Blue_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Blue SubGroup' , tracks = octave_colors ( 'Blue' , 'three_seven' ) } ,
  
    -- Octave SubGroups VIOLET Color vl
    oct_zero_nine_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Violet SubGroup' , tracks = octave_colors ( 'Violet' , 'zero_nine' ) } ,
   oct_zero_three_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Violet SubGroup' , tracks = octave_colors ( 'Violet' , 'zero_three' ) } ,
     oct_four_six_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Violet SubGroup' , tracks = octave_colors ( 'Violet' , 'four_six' ) } ,
   oct_seven_nine_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Violet SubGroup' , tracks = octave_colors ( 'Violet' , 'seven_nine' ) } ,
  oct_three_seven_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Violet SubGroup' , tracks = octave_colors ( 'Violet' , 'three_seven' ) } ,
  
    -- Octave SubGroups WHITE Color wh
    oct_zero_nine_white = { color = White_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves White SubGroup' , tracks = octave_colors ( 'White' , 'zero_nine' ) } ,
   oct_zero_three_white = { color = White_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves White SubGroup' , tracks = octave_colors ( 'White' , 'zero_three' ) } ,
     oct_four_six_white = { color = White_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves White SubGroup' , tracks = octave_colors ( 'White' , 'four_six' ) } ,
   oct_seven_nine_white = { color = White_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves White SubGroup' , tracks = octave_colors ( 'White' , 'seven_nine' ) } ,
  oct_three_seven_white = { color = White_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves White SubGroup' , tracks = octave_colors ( 'White' , 'three_seven' ) } ,
  
    -- Octave SubGroups YELLOW Color yl
    oct_zero_nine_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = '0-9 Octaves Yellow SubGroup' , tracks = octave_colors ( 'Yellow' , 'zero_nine' ) } ,
   oct_zero_three_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = '0-3 Octaves Yellow SubGroup' , tracks = octave_colors ( 'Yellow' , 'zero_three' ) } ,
     oct_four_six_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = '4-6 Octaves Yellow SubGroup' , tracks = octave_colors ( 'Yellow' , 'four_six' ) } ,
   oct_seven_nine_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = '7-9 Octaves Yellow SubGroup' , tracks = octave_colors ( 'Yellow' , 'seven_nine' ) } ,
  oct_three_seven_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = '4-7 Octaves Yellow SubGroup' , tracks = octave_colors ( 'Yellow' , 'three_seven' ) } ,

}


--------------------------------------------------------------------------------
-- SUBGROUPS COLORS
--------------------------------------------------------------------------------
sgroup_settings = {

  -- SubGroups AQUA Color aq
    sgroup_two_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'two' ) } ,
  sgroup_three_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'three' ) } ,
   sgroup_four_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'four' ) } ,
   sgroup_five_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'five' ) } ,
    sgroup_six_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'six' ) } ,
  sgroup_seven_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'seven' ) } ,
  sgroup_eight_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Aqua Tracks' , tracks = track_colors ( 'Aqua' , 'eight' ) } ,

  -- SubGroups BLACK Color bk
    sgroup_two_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Black Tracks' , tracks = track_colors ( 'Black' , 'two' ) } ,
  sgroup_three_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Black Tracks' , tracks = track_colors ( 'Black' , 'three' ) } ,
   sgroup_four_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Black Tracks' , tracks = track_colors ( 'Black' , 'four' ) } ,
   sgroup_five_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Black Tracks' , tracks = track_colors ( 'Black' , 'five' ) } ,
    sgroup_six_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Black Tracks' , tracks = track_colors ( 'Black' , 'six' ) } ,
  sgroup_seven_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Black Tracks' , tracks = track_colors ( 'Black' , 'seven' ) } ,
  sgroup_eight_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Black Tracks' , tracks = track_colors ( 'Black' , 'eight' ) } ,

  -- SubGroups BLUE Color bl
    sgroup_two_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Blue Tracks' , tracks = track_colors ( 'Blue' , 'two' ) } ,
  sgroup_three_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Blue Tracks' , tracks = track_colors ( 'Blue' , 'three' ) } ,
   sgroup_four_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Blue Tracks' , tracks = track_colors ( 'Blue' , 'four' ) } ,
   sgroup_five_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Blue Tracks' , tracks = track_colors ( 'Blue' , 'five' ) } ,
    sgroup_six_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Blue Tracks' , tracks = track_colors ( 'Blue' , 'six' ) } ,
  sgroup_seven_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Blue Tracks' , tracks = track_colors ( 'Blue' , 'seven' ) } ,
  sgroup_eight_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Blue Tracks' , tracks = track_colors ( 'Blue' , 'eight' ) } ,

  -- SubGroups BROWN Color br
    sgroup_two_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Brown Tracks' , tracks = track_colors ( 'Brown' , 'two' ) } ,
  sgroup_three_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Brown Tracks' , tracks = track_colors ( 'Brown' , 'three' ) } ,
   sgroup_four_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Brown Tracks' , tracks = track_colors ( 'Brown' , 'four' ) } ,
   sgroup_five_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Brown Tracks' , tracks = track_colors ( 'Brown' , 'five' ) } ,
    sgroup_six_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Brown Tracks' , tracks = track_colors ( 'Brown' , 'six' ) } ,
  sgroup_seven_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Brown Tracks' , tracks = track_colors ( 'Brown' , 'seven' ) } ,
  sgroup_eight_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Brown Tracks' , tracks = track_colors ( 'Brown' , 'eight' ) } ,

  -- SubGroups GOLD Color gl
    sgroup_two_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Gold Tracks' , tracks = track_colors ( 'Gold' , 'two' ) } ,
  sgroup_three_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Gold Tracks' , tracks = track_colors ( 'Gold' , 'three' ) } ,
   sgroup_four_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Gold Tracks' , tracks = track_colors ( 'Gold' , 'four' ) } ,
   sgroup_five_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Gold Tracks' , tracks = track_colors ( 'Gold' , 'five' ) } ,
    sgroup_six_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Gold Tracks' , tracks = track_colors ( 'Gold' , 'six' ) } ,
  sgroup_seven_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Gold Tracks' , tracks = track_colors ( 'Gold' , 'seven' ) } ,
  sgroup_eight_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Gold Tracks' , tracks = track_colors ( 'Gold' , 'eight' ) } ,

  -- SubGroups GRAY Color gy
    sgroup_two_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Gray Tracks' , tracks = track_colors ( 'Gray' , 'two' ) } ,
  sgroup_three_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Gray Tracks' , tracks = track_colors ( 'Gray' , 'three' ) } ,
   sgroup_four_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Gray Tracks' , tracks = track_colors ( 'Gray' , 'four' ) } ,
   sgroup_five_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Gray Tracks' , tracks = track_colors ( 'Gray' , 'five' ) } ,
    sgroup_six_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Gray Tracks' , tracks = track_colors ( 'Gray' , 'six' ) } ,
  sgroup_seven_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Gray Tracks' , tracks = track_colors ( 'Gray' , 'seven' ) } ,
  sgroup_eight_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Gray Tracks' , tracks = track_colors ( 'Gray' , 'eight' ) } ,

  -- SubGroups GREEN Color gr
    sgroup_two_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Green Tracks' , tracks = track_colors ( 'Green' , 'two' ) } ,
  sgroup_three_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Green Tracks' , tracks = track_colors ( 'Green' , 'three' ) } ,
   sgroup_four_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Green Tracks' , tracks = track_colors ( 'Green' , 'four' ) } ,
   sgroup_five_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Green Tracks' , tracks = track_colors ( 'Green' , 'five' ) } ,
    sgroup_six_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Green Tracks' , tracks = track_colors ( 'Green' , 'six' ) } ,
  sgroup_seven_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Green Tracks' , tracks = track_colors ( 'Green' , 'seven' ) } ,
  sgroup_eight_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Green Tracks' , tracks = track_colors ( 'Green' , 'eight' ) } ,

  -- SubGroups ORANGE Color or
    sgroup_two_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Orange Tracks' , tracks = track_colors ( 'Orange' , 'two' ) } ,
  sgroup_three_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Orange Tracks' , tracks = track_colors ( 'Orange' , 'three' ) } ,
   sgroup_four_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Orange Tracks' , tracks = track_colors ( 'Orange' , 'four' ) } ,
   sgroup_five_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Orange Tracks' , tracks = track_colors ( 'Orange' , 'five' ) } ,
    sgroup_six_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Orange Tracks' , tracks = track_colors ( 'Orange' , 'six' ) } ,
  sgroup_seven_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Orange Tracks' , tracks = track_colors ( 'Orange' , 'seven' ) } ,
  sgroup_eight_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Orange Tracks' , tracks = track_colors ( 'Orange' , 'eight' ) } ,

  -- SubGroups PALE PINK Color pl
    sgroup_two_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'two' ) } ,
  sgroup_three_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'three' ) } ,
   sgroup_four_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'four' ) } ,
   sgroup_five_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'five' ) } ,
    sgroup_six_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'six' ) } ,
  sgroup_seven_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'seven' ) } ,
  sgroup_eight_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Pale_Pink Tracks' , tracks = track_colors ( 'Pale_Pink' , 'eight' ) } ,

  -- SubGroups PINK Color pn
    sgroup_two_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Pink Tracks' , tracks = track_colors ( 'Pink' , 'two' ) } ,
  sgroup_three_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Pink Tracks' , tracks = track_colors ( 'Pink' , 'three' ) } ,
   sgroup_four_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Pink Tracks' , tracks = track_colors ( 'Pink' , 'four' ) } ,
   sgroup_five_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Pink Tracks' , tracks = track_colors ( 'Pink' , 'five' ) } ,
    sgroup_six_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Pink Tracks' , tracks = track_colors ( 'Pink' , 'six' ) } ,
  sgroup_seven_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Pink Tracks' , tracks = track_colors ( 'Pink' , 'seven' ) } ,
  sgroup_eight_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Pink Tracks' , tracks = track_colors ( 'Pink' , 'eight' ) } ,

  -- SubGroups PISTACHIO Color ps
    sgroup_two_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'two' ) } ,
  sgroup_three_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'three' ) } ,
   sgroup_four_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'four' ) } ,
   sgroup_five_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'five' ) } ,
    sgroup_six_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'six' ) } ,
  sgroup_seven_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'seven' ) } ,
  sgroup_eight_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Pistachio Tracks' , tracks = track_colors ( 'Pistachio' , 'eight' ) } ,

  -- SubGroups RED Color rd
    sgroup_one_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Red Track' ,  tracks = track_colors ( 'Red' , 'a2' ) } ,
    sgroup_two_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Red Tracks' , tracks = track_colors ( 'Red' , 'two' ) } ,
  sgroup_three_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Red Tracks' , tracks = track_colors ( 'Red' , 'three' ) } ,
   sgroup_four_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Red Tracks' , tracks = track_colors ( 'Red' , 'four' ) } ,
   sgroup_five_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Red Tracks' , tracks = track_colors ( 'Red' , 'five' ) } ,
    sgroup_six_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Red Tracks' , tracks = track_colors ( 'Red' , 'six' ) } ,
  sgroup_seven_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Red Tracks' , tracks = track_colors ( 'Red' , 'seven' ) } ,
  sgroup_eight_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Red Tracks' , tracks = track_colors ( 'Red' , 'eight' ) } ,

  -- SubGroups SKY BLUE Color sk
    sgroup_two_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'two' ) } ,
  sgroup_three_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'three' ) } ,
   sgroup_four_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'four' ) } ,
   sgroup_five_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'five' ) } ,
    sgroup_six_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'six' ) } ,
  sgroup_seven_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'seven' ) } ,
  sgroup_eight_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Sky_Blue Tracks' , tracks = track_colors ( 'Sky_Blue' , 'eight' ) } ,

  -- SubGroups VIOLET Color vl
    sgroup_two_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Violet Tracks' , tracks = track_colors ( 'Violet' , 'two' ) } ,
  sgroup_three_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Violet Tracks' , tracks = track_colors ( 'Violet' , 'three' ) } ,
   sgroup_four_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Violet Tracks' , tracks = track_colors ( 'Violet' , 'four' ) } ,
   sgroup_five_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Violet Tracks' , tracks = track_colors ( 'Violet' , 'five' ) } ,
    sgroup_six_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Violet Tracks' , tracks = track_colors ( 'Violet' , 'six' ) } ,
  sgroup_seven_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Violet Tracks' , tracks = track_colors ( 'Violet' , 'seven' ) } ,
  sgroup_eight_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Violet Tracks' , tracks = track_colors ( 'Violet' , 'eight' ) } ,

  -- SubGroups WHITE Color wh
    sgroup_two_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 White Tracks' , tracks = track_colors ( 'White' , 'two' ) } ,
  sgroup_three_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 White Tracks' , tracks = track_colors ( 'White' , 'three' ) } ,
   sgroup_four_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 White Tracks' , tracks = track_colors ( 'White' , 'four' ) } ,
   sgroup_five_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 White Tracks' , tracks = track_colors ( 'White' , 'five' ) } ,
    sgroup_six_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 White Tracks' , tracks = track_colors ( 'White' , 'six' ) } ,
  sgroup_seven_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 White Tracks' , tracks = track_colors ( 'White' , 'seven' ) } ,
  sgroup_eight_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 White Tracks' , tracks = track_colors ( 'White' , 'eight' ) } ,

  -- SubGroups YELLOW Color yl
    sgroup_two_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x2 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'two' ) } ,
  sgroup_three_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x3 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'three' ) } ,
   sgroup_four_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x4 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'four' ) } ,
   sgroup_five_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x5 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'five' ) } ,
    sgroup_six_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x6 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'six' ) } ,
  sgroup_seven_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x7 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'seven' ) } ,
  sgroup_eight_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x8 Yellow Tracks' , tracks = track_colors ( 'Yellow' , 'eight' ) } ,

}


--------------------------------------------------------------------------------
-- GROUPS & MAIN GROUPS COLORS
--------------------------------------------------------------------------------
group_settings = {

  -- Group & Main Group AQUA Color aq
   sgroup_one_aqua = { color = Aqua_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Aqua Aux Track' } , --sgr
    group_one_aqua = { color = Aqua_zero , color_blend = 32 , collapsed = F , name = 'GROUP AQUA 01' } ,
    group_two_aqua = { color = Aqua_zero , color_blend = 32 , collapsed = F , name = 'GROUP AQUA 02' } ,
  group_three_aqua = { color = Aqua_zero , color_blend = 32 , collapsed = F , name = 'GROUP AQUA 03' } ,
   group_four_aqua = { color = Aqua_zero , color_blend = 32 , collapsed = F , name = 'GROUP AQUA 04' } ,
   group_five_aqua = { color = Aqua_zero , color_blend = 32 , collapsed = F , name = 'GROUP AQUA 05' } ,
   main_group_aqua = { color = Aqua_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP AQUA' } ,

  -- Group & Main Group BLACK Color bk
   sgroup_one_black = { color = Black_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Black Aux Track' } , --sgr
    group_one_black = { color = Black_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLACK 01' } ,
    group_two_black = { color = Black_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLACK 02' } ,
  group_three_black = { color = Black_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLACK 03' } ,
   group_four_black = { color = Black_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLACK 04' } ,
   group_five_black = { color = Black_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLACK 05' } ,
   main_group_black = { color = Black_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP BLACK' } ,

  -- Group & Main Group BLUE Color bl
   sgroup_one_blue = { color = Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Blue Aux Track' } , --sgr
    group_one_blue = { color = Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLUE 01' } ,
    group_two_blue = { color = Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLUE 02' } ,
  group_three_blue = { color = Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLUE 03' } ,
   group_four_blue = { color = Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLUE 04' } ,
   group_five_blue = { color = Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP BLUE 05' } ,
   main_group_blue = { color = Blue_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP BLUE' } ,

  -- Group & Main Group BROWN Color br
   sgroup_one_brown = { color = Brown_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Brown Aux Track' } , --sgr
    group_one_brown = { color = Brown_zero , color_blend = 32 , collapsed = F , name = 'GROUP BROWN 01' } ,
    group_two_brown = { color = Brown_zero , color_blend = 32 , collapsed = F , name = 'GROUP BROWN 02' } ,
  group_three_brown = { color = Brown_zero , color_blend = 32 , collapsed = F , name = 'GROUP BROWN 03' } ,
   group_four_brown = { color = Brown_zero , color_blend = 32 , collapsed = F , name = 'GROUP BROWN 04' } ,
   group_five_brown = { color = Brown_zero , color_blend = 32 , collapsed = F , name = 'GROUP BROWN 05' } ,
   main_group_brown = { color = Brown_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP BROWN' } ,

  -- Group & Main Group GOLD Color gl
   sgroup_one_gold = { color = Gold_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Gold Aux Track' } , --sgr
    group_one_gold = { color = Gold_zero , color_blend = 32 , collapsed = F , name = 'GROUP GOLD 01' } ,
    group_two_gold = { color = Gold_zero , color_blend = 32 , collapsed = F , name = 'GROUP GOLD 02' } ,
  group_three_gold = { color = Gold_zero , color_blend = 32 , collapsed = F , name = 'GROUP GOLD 03' } ,
   group_four_gold = { color = Gold_zero , color_blend = 32 , collapsed = F , name = 'GROUP GOLD 04' } ,
   group_five_gold = { color = Gold_zero , color_blend = 32 , collapsed = F , name = 'GROUP GOLD 05' } ,
   main_group_gold = { color = Gold_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP GOLD' } ,

  -- Group & Main Group GRAY Color gy
   sgroup_one_gray = { color = Gray_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Gray Aux Track' } , --sgr
    group_one_gray = { color = Gray_zero , color_blend = 32 , collapsed = F , name = 'GROUP GRAY 01' } ,
    group_two_gray = { color = Gray_zero , color_blend = 32 , collapsed = F , name = 'GROUP GRAY 02' } ,
  group_three_gray = { color = Gray_zero , color_blend = 32 , collapsed = F , name = 'GROUP GRAY 03' } ,
   group_four_gray = { color = Gray_zero , color_blend = 32 , collapsed = F , name = 'GROUP GRAY 04' } ,
   group_five_gray = { color = Gray_zero , color_blend = 32 , collapsed = F , name = 'GROUP GRAY 05' } ,
   main_group_gray = { color = Gray_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP GRAY' } ,

  -- Group & Main Group GREEN Color gr
   sgroup_one_green = { color = Green_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Green Aux Track' } , --sgr
    group_one_green = { color = Green_zero , color_blend = 32 , collapsed = F , name = 'GROUP GREEN 01' } ,
    group_two_green = { color = Green_zero , color_blend = 32 , collapsed = F , name = 'GROUP GREEN 02' } ,
  group_three_green = { color = Green_zero , color_blend = 32 , collapsed = F , name = 'GROUP GREEN 03' } ,
   group_four_green = { color = Green_zero , color_blend = 32 , collapsed = F , name = 'GROUP GREEN 04' } ,
   group_five_green = { color = Green_zero , color_blend = 32 , collapsed = F , name = 'GROUP GREEN 05' } ,
   main_group_green = { color = Green_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP GREEN' } ,

  -- Group & Main Group ORANGE Color or
   sgroup_one_orange = { color = Orange_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Orange Aux Track' } , --sgr
    group_one_orange = { color = Orange_zero , color_blend = 32 , collapsed = F , name = 'GROUP ORANGE 01' } ,
    group_two_orange = { color = Orange_zero , color_blend = 32 , collapsed = F , name = 'GROUP ORANGE 02' } ,
  group_three_orange = { color = Orange_zero , color_blend = 32 , collapsed = F , name = 'GROUP ORANGE 03' } ,
   group_four_orange = { color = Orange_zero , color_blend = 32 , collapsed = F , name = 'GROUP ORANGE 04' } ,
   group_five_orange = { color = Orange_zero , color_blend = 32 , collapsed = F , name = 'GROUP ORANGE 05' } ,
   main_group_orange = { color = Orange_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP ORANGE' } ,

  -- Group & Main Group PALE PINK Color pl
   sgroup_one_pale = { color = Pale_Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Pale_Pink Aux Track' } , --sgr
    group_one_pale = { color = Pale_Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PALE_PINK 01' } ,
    group_two_pale = { color = Pale_Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PALE_PINK 02' } ,
  group_three_pale = { color = Pale_Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PALE_PINK 03' } ,
   group_four_pale = { color = Pale_Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PALE_PINK 04' } ,
   group_five_pale = { color = Pale_Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PALE_PINK 05' } ,
   main_group_pale = { color = Pale_Pink_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP PALE_PINK' } ,

  -- Group & Main Group PINK Color pn
   sgroup_one_pink = { color = Pink_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Pink Aux Track' } , --sgr
    group_one_pink = { color = Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PINK 01' } ,
    group_two_pink = { color = Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PINK 02' } ,
  group_three_pink = { color = Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PINK 03' } ,
   group_four_pink = { color = Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PINK 04' } ,
   group_five_pink = { color = Pink_zero , color_blend = 32 , collapsed = F , name = 'GROUP PINK 05' } ,
   main_group_pink = { color = Pink_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP PINK' } ,

  -- Group & Main Group PISTACHIO Color ps
   sgroup_one_pista = { color = Pistachio_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Pistachio Aux Track' } , --sgr
    group_one_pista = { color = Pistachio_zero , color_blend = 32 , collapsed = F , name = 'GROUP PISTACHIO 01' } ,
    group_two_pista = { color = Pistachio_zero , color_blend = 32 , collapsed = F , name = 'GROUP PISTACHIO 02' } ,
  group_three_pista = { color = Pistachio_zero , color_blend = 32 , collapsed = F , name = 'GROUP PISTACHIO 03' } ,
   group_four_pista = { color = Pistachio_zero , color_blend = 32 , collapsed = F , name = 'GROUP PISTACHIO 04' } ,
   group_five_pista = { color = Pistachio_zero , color_blend = 32 , collapsed = F , name = 'GROUP PISTACHIO 05' } ,
   main_group_pista = { color = Pistachio_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP PISTACHIO' } ,

  -- Group & Main Group RED Color rd
   sgroup_one_red = { color = Red_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Red Aux Track' } , --sgr
    group_one_red = { color = Red_zero , color_blend = 32 , collapsed = F , name = 'GROUP RED 01' } ,
    group_two_red = { color = Red_zero , color_blend = 32 , collapsed = F , name = 'GROUP RED 02' } ,
  group_three_red = { color = Red_zero , color_blend = 32 , collapsed = F , name = 'GROUP RED 03' } ,
   group_four_red = { color = Red_zero , color_blend = 32 , collapsed = F , name = 'GROUP RED 04' } ,
   group_five_red = { color = Red_zero , color_blend = 32 , collapsed = F , name = 'GROUP RED 05' } ,
   main_group_red = { color = Red_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP RED' } ,

  -- Group & Main Group SKY BLUE Color sk
   sgroup_one_sky = { color = Sky_Blue_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Sky_Blue Aux Track' } , --sgr
    group_one_sky = { color = Sky_Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP SKY_BLUE 01' } ,
    group_two_sky = { color = Sky_Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP SKY_BLUE 02' } ,
  group_three_sky = { color = Sky_Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP SKY_BLUE 03' } ,
   group_four_sky = { color = Sky_Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP SKY_BLUE 04' } ,
   group_five_sky = { color = Sky_Blue_zero , color_blend = 32 , collapsed = F , name = 'GROUP SKY_BLUE 05' } ,
   main_group_sky = { color = Sky_Blue_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP SKY_BLUE' } ,

  -- Group & Main Group VIOLET Color vl
   sgroup_one_violet = { color = Violet_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Violet Aux Track' } , --sgr
    group_one_violet = { color = Violet_zero , color_blend = 32 , collapsed = F , name = 'GROUP VIOLET 01' } ,
    group_two_violet = { color = Violet_zero , color_blend = 32 , collapsed = F , name = 'GROUP VIOLET 02' } ,
  group_three_violet = { color = Violet_zero , color_blend = 32 , collapsed = F , name = 'GROUP VIOLET 03' } ,
   group_four_violet = { color = Violet_zero , color_blend = 32 , collapsed = F , name = 'GROUP VIOLET 04' } ,
   group_five_violet = { color = Violet_zero , color_blend = 32 , collapsed = F , name = 'GROUP VIOLET 05' } ,
   main_group_violet = { color = Violet_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP VIOLET' } ,

  -- Group & Main Group WHITE Color wh
   sgroup_one_white = { color = White_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 White Aux Track' } , --sgr
    group_one_white = { color = White_zero , color_blend = 32 , collapsed = F , name = 'GROUP WHITE 01' } ,
    group_two_white = { color = White_zero , color_blend = 32 , collapsed = F , name = 'GROUP WHITE 02' } ,
  group_three_white = { color = White_zero , color_blend = 32 , collapsed = F , name = 'GROUP WHITE 03' } ,
   group_four_white = { color = White_zero , color_blend = 32 , collapsed = F , name = 'GROUP WHITE 04' } ,
   group_five_white = { color = White_zero , color_blend = 32 , collapsed = F , name = 'GROUP WHITE 05' } ,
   main_group_white = { color = White_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP WHITE' } ,

  -- Group & Main Group YELLOW Color yl
   sgroup_one_yellow = { color = Yellow_zero , color_blend = 23 , collapsed = F , name = 'SubGroup x1 Yellow Aux Track' } , --sgr
    group_one_yellow = { color = Yellow_zero , color_blend = 32 , collapsed = F , name = 'GROUP YELLOW 01' } ,
    group_two_yellow = { color = Yellow_zero , color_blend = 32 , collapsed = F , name = 'GROUP YELLOW 02' } ,
  group_three_yellow = { color = Yellow_zero , color_blend = 32 , collapsed = F , name = 'GROUP YELLOW 03' } ,
   group_four_yellow = { color = Yellow_zero , color_blend = 32 , collapsed = F , name = 'GROUP YELLOW 04' } ,
   group_five_yellow = { color = Yellow_zero , color_blend = 32 , collapsed = F , name = 'GROUP YELLOW 05' } ,
   main_group_yellow = { color = Yellow_zero , color_blend = 42 , collapsed = F , name = 'MAIN GROUP YELLOW' } ,

}


--------------------------------------------------------------------------------
-- FUNCTIONS INSERT
--------------------------------------------------------------------------------

-- Insert Tracks Only
function insert_tro( track_index , track_setting )
  renoise.song():insert_track_at(track_index)
  local track = renoise.song():track( track_index )
  track.visible_effect_columns = 0 , 1 , false
  for parameter_name, parameter_value in pairs( track_setting ) do
   track[ parameter_name ] = parameter_value
  end
  local column_names = { 'Note 01' , 'Note 02' , 'Note 03' , 'Note 04' , 'Note 05' , 'Note 06' , 'Note 07' , 'Note 08' , 'Note 09' , 'Note 10' , 'Note 11' , 'Note 12' }
  --local column_names = { 'C  do' , 'C#' , 'D  re' , 'D#' , 'E  mi' , 'F  fa' , 'F#' , 'G  sol' , 'G#' , 'A  la' , 'A#' , 'B  si' }
  for note_column = 1 , 12 do
    track:set_column_name( note_column , column_names[ note_column ] )
  end
end

--Insert Tracks , SubGroups & Octaves
function insert_track( track_index , group_index , track_setting ) --tracks
  renoise.song():insert_track_at( track_index )
  local track = renoise.song():track( track_index )
  track.visible_effect_columns = 0 , 1 , false  -- track.visible_note_columns, track.volume_column_visible
  for parameter_name , parameter_value in pairs( track_setting ) do
   track[ parameter_name ] = parameter_value
  end
  local column_names = { 'Note 01' , 'Note 02' , 'Note 03' , 'Note 04' , 'Note 05' , 'Note 06' , 'Note 07' , 'Note 08' , 'Note 09' , 'Note 10' , 'Note 11' , 'Note 12' }
  for note_column = 1 , 12 do
    track:set_column_name( note_column , column_names[ note_column ] )
  end
  renoise.song():add_track_to_group( track_index , group_index )
end

function i_sgr( group_setting ) --subgroups
  local song = renoise.song()
  local i , group_index , group_setting = 1 , song.selected_track_index + 1 , sgroup_settings[ group_setting ]
  song:insert_group_at( group_index )
  for parameter_name , parameter_value in pairs( group_setting ) do
    if not ( parameter_name == 'tracks' ) then
      song:track( group_index )[ parameter_name ] = parameter_value
    end
  end
  for _ , track_setting in ipairs( group_setting.tracks ) do
    local group_index = group_index + i
    i = i + 1
    insert_track(song.selected_track_index , group_index , track_setting)
  end
  song.tracks[ song.selected_track_index + 1 ].group_parent.collapsed = true  -- collapse FX in Group
end
---
function insert_octave( track_index , group_index , track_setting ) --tracks
  renoise.song():insert_track_at( track_index )
  local track = renoise.song():track( track_index )
  track.visible_effect_columns, track.visible_note_columns = 0 , 12 , false  -- track.visible_note_columns (show all 12 note columns), track.volume_column_visible
  for parameter_name , parameter_value in pairs( track_setting ) do
   track[ parameter_name ] = parameter_value
  end
  local column_names = { 'C  do' , 'C#' , 'D  re' , 'D#' , 'E  mi' , 'F  fa' , 'F#' , 'G  sol' , 'G#' , 'A  la' , 'A#' , 'B  si' }
  for note_column = 1 , 12 do
    track:set_column_name( note_column , column_names[ note_column ] )
  end
  renoise.song():add_track_to_group( track_index , group_index )
end

function i_oct( group_setting ) --octaves
  local song = renoise.song()
  local i , group_index , group_setting = 1 , song.selected_track_index + 1 , octave_settings[ group_setting ]
  song:insert_group_at( group_index )
  for parameter_name , parameter_value in pairs( group_setting ) do
    if not ( parameter_name == 'tracks' ) then
      song:track( group_index )[ parameter_name ] = parameter_value
    end
  end
  for _ , track_setting in ipairs( group_setting.tracks ) do
    local group_index = group_index + i
    i = i + 1
    insert_octave(song.selected_track_index , group_index , track_setting)
  end
  song.tracks[ song.selected_track_index + 1 ].group_parent.collapsed = true  -- collapse FX in Group
  song:track(song.selected_track_index + 1).collapsed = false
end



-- Insert Groups
function i_gr( group_setting )
  local song = renoise.song()
  local i , group_index , group_setting = 1 , song.selected_track_index + 1 , group_settings[ group_setting ]
  song:insert_group_at( group_index )
  for parameter_name , parameter_value in pairs( group_setting ) do
    if not ( parameter_name == 'tracks' ) then
      song:track( group_index )[ parameter_name ] = parameter_value
    end
  end
end

-- Insert SubGroups to Group
function i_sgr_gr( a , b , c , d )
  local song = renoise.song()
  song:add_track_to_group( song.selected_track_index + a , song.selected_track_index + b ) --  2 + 2     = 4
  song:add_track_to_group( song.selected_track_index + c , song.selected_track_index + a ) --  4 + 2 + 1 = 7
  song.tracks[ song.selected_track_index + d ].group_parent.collapsed = true
end
--[[
i_sgr_gr( 4 , 1 , 7 , 6 )    --2Gx2T
i_sgr_gr( 5 , 1 , 9 , 8 )    --2Gx3T
i_sgr_gr( 6 , 1 , 11 , 10 )  --2Gx4T
i_sgr_gr( 7 , 1 , 13 , 12 )  --2Gx5T
i_sgr_gr( 8 , 1 , 15 , 14 )  --2Gx6T
i_sgr_gr( 9 , 1 , 17 , 16 )  --2Gx7T
i_sgr_gr( 10 , 1 , 19 , 18 ) --2Gx8T
--]]


-- Insert Main Group
function i_mgr( group_setting )
  local song = renoise.song()
  local i , group_index , group_setting = 1 , song.selected_track_index + 1 , group_settings[ group_setting ]
  song:insert_group_at( group_index )
  for parameter_name , parameter_value in pairs( group_setting ) do
    if not ( parameter_name == 'tracks' ) then
      song:track( group_index )[ parameter_name ] = parameter_value
    end
  end
end

-- Insert Groups to Maing Group
function i_gr_mgr( a , b , c , d )
  local song = renoise.song()
  song:add_track_to_group( song.selected_track_index + a , song.selected_track_index + b )
  song:add_track_to_group( song.selected_track_index + c , song.selected_track_index + a )
  song.tracks[ song.selected_track_index + d ].group_parent.collapsed = true
end
--[[
i_gr_mgr( 8 , 1 , 15 , 14 )  --2Gx2T
i_gr_mgr( 10 , 1 , 19 , 18 ) --2Gx3T
i_gr_mgr( 12 , 1 , 23 , 22 ) --2Gx4T
i_gr_mgr( 14 , 1 , 27 , 26 ) --2Gx5T
i_gr_mgr( 16 , 1 , 31 , 30 ) --2Gx6T
i_gr_mgr( 18 , 1 , 35 , 34 ) --2Gx7T
i_gr_mgr( 20 , 1 , 39 , 38 ) --2Gx8T
--]]


--------------------------------------------------------------------------------
-- MAIN GROUPS SELECT
--------------------------------------------------------------------------------
function  mgr_select ( switch , popup ) -- ( 16 , 8 )

  local clr , C , track = '' , '' , {}
      if switch ==  1 then clr = '_aqua'      C = 'Aqua'
  elseif switch ==  2 then clr = '_black'     C = 'Black'
  elseif switch ==  3 then clr = '_blue'      C = 'Blue'
  elseif switch ==  4 then clr = '_brown'     C = 'Brown'
  elseif switch ==  5 then clr = '_gold'      C = 'Gold'
  elseif switch ==  6 then clr = '_gray'      C = 'Gray'
  elseif switch ==  7 then clr = '_green'     C = 'Green'
  elseif switch ==  8 then clr = '_orange'    C = 'Orange'
  elseif switch ==  9 then clr = '_pale'      C = 'Pale_Pink'
  elseif switch == 10 then clr = '_pink'      C = 'Pink'
  elseif switch == 11 then clr = '_pista'     C = 'Pistachio'
  elseif switch == 12 then clr = '_red'       C = 'Red'
  elseif switch == 13 then clr = '_sky'       C = 'Sky_Blue'
  elseif switch == 14 then clr = '_violet'    C = 'Violet'
  elseif switch == 15 then clr = '_white'     C = 'White'
  elseif switch == 16 then clr = '_yellow'    C = 'Yellow'
  end

   local TWO = _G[ C..'_two' ] -- G_C_two
    track.a2 = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }

  -- 1 Main Group x 2 Groups [2 SubGroups x 2 Tracks] 
      if popup == 1 then
    i_sgr( 'sgroup_two'..clr ) i_sgr( 'sgroup_two'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr( 'sgroup_two'..clr ) i_sgr( 'sgroup_two'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr( 'main_group'..clr ) 
    i_gr_mgr( 8 , 1 , 15 , 14 )

  -- 1 Main Group x 2 Groups [2 SubGroups x 3 Tracks]     
  elseif popup == 2 then
    i_sgr( 'sgroup_three'..clr ) i_sgr( 'sgroup_three'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 5 , 1 , 9 , 8 )
    i_sgr( 'sgroup_three'..clr ) i_sgr( 'sgroup_three'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 5 , 1 , 9 , 8 )
    i_mgr( 'main_group'..clr )
    i_gr_mgr( 10 , 1 , 19 , 18 )

  -- 1 Main Group x 2 Groups [2 SubGroups x 4 Tracks]  
  elseif popup == 3 then
    i_sgr( 'sgroup_four'..clr ) i_sgr( 'sgroup_four'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )
        i_sgr( 'sgroup_four'..clr ) i_sgr( 'sgroup_four'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )
        i_mgr( 'main_group'..clr )
    i_gr_mgr( 12 , 1 , 23 , 22 )

  -- 1 Main Group x 2 Groups [2 SubGroups x 5 Tracks]
  elseif popup == 4 then
    i_sgr( 'sgroup_five'..clr ) i_sgr( 'sgroup_five'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 7 , 1 , 13 , 12 )
    i_sgr( 'sgroup_five'..clr ) i_sgr( 'sgroup_five'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 7 , 1 , 13 , 12 )
    i_mgr( 'main_group'..clr )
    i_gr_mgr( 14 , 1 , 27 , 26 )
  
  -- 1 Main Group x 2 Groups [2 SubGroups x 6 Tracks]
  elseif popup == 5 then
    i_sgr( 'sgroup_six'..clr ) i_sgr( 'sgroup_six'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr( 'sgroup_six'..clr ) i_sgr( 'sgroup_six'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr( 'main_group'..clr )
    i_gr_mgr( 16 , 1 , 31 , 30 )
  
  -- 1 Main Group x 2 Groups [2 SubGroups x 7 Tracks]
  elseif popup == 6 then
    i_sgr( 'sgroup_seven'..clr ) i_sgr( 'sgroup_seven'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 9 , 1 , 17 , 16 )
    i_sgr( 'sgroup_seven'..clr ) i_sgr( 'sgroup_seven'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 9 , 1 , 17 , 16 )
    i_mgr( 'main_group'..clr )
    i_gr_mgr( 18 , 1 , 35 , 34 )
  
  -- 1 Main Group x 2 Groups [2 SubGroups x 8 Tracks]
  elseif popup == 7 then
    i_sgr( 'sgroup_eight'..clr ) i_sgr( 'sgroup_eight'..clr ) i_gr( 'group_two'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr( 'sgroup_eight'..clr ) i_sgr( 'sgroup_eight'..clr ) i_gr( 'group_one'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
    i_mgr( 'main_group'..clr )
    i_gr_mgr( 20 , 1 , 39 , 38 )

  -- 1 Main Group [1 Aux Track]  
  elseif popup == 8 then
    local song = renoise.song()
    insert_tro( song.selected_track_index + 1, track.a2 ) i_mgr( 'main_group'..clr )
    song:add_track_to_group ( song.selected_track_index + 2 , song.selected_track_index + 1 ) song:select_next_track()
  end

end


--------------------------------------------------------------------------------
-- GROUPS SELECT (NOT MAIN GROUP)
--------------------------------------------------------------------------------
function  gr_select ( switch , popup ) -- ( 16 , 19 )

  local clr , C , track = '' , '' , {}
      if switch ==  1 then clr = '_aqua'      C = 'Aqua'
  elseif switch ==  2 then clr = '_black'     C = 'Black'
  elseif switch ==  3 then clr = '_blue'      C = 'Blue'
  elseif switch ==  4 then clr = '_brown'     C = 'Brown'
  elseif switch ==  5 then clr = '_gold'      C = 'Gold'
  elseif switch ==  6 then clr = '_gray'      C = 'Gray'
  elseif switch ==  7 then clr = '_green'     C = 'Green'
  elseif switch ==  8 then clr = '_orange'    C = 'Orange'
  elseif switch ==  9 then clr = '_pale'      C = 'Pale_Pink'
  elseif switch == 10 then clr = '_pink'      C = 'Pink'
  elseif switch == 11 then clr = '_pista'     C = 'Pistachio'
  elseif switch == 12 then clr = '_red'       C = 'Red'
  elseif switch == 13 then clr = '_sky'       C = 'Sky_Blue'
  elseif switch == 14 then clr = '_violet'    C = 'Violet'
  elseif switch == 15 then clr = '_white'     C = 'White'
  elseif switch == 16 then clr = '_yellow'    C = 'Yellow'
  end

   local TWO = _G[ C..'_two' ] -- G_C_two
   track.a2 = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }

  -- 1Gr [2SGr x 2Tr]
      if popup == 1 then
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )

  -- 1Gr [2SGr x 3Tr]
  elseif popup == 2 then
    i_sgr ( 'sgroup_three'..clr ) i_sgr ( 'sgroup_three'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 5 , 1 , 9 , 8 )

  -- 1Gr [2SGr x 4Tr]
  elseif popup == 3 then
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )

  -- 1Gr [2SGr x 5Tr]
  elseif popup == 4 then
    i_sgr ( 'sgroup_five'..clr ) i_sgr ( 'sgroup_five'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 7 , 1 , 13 , 12 )

  -- 1Gr [2SGr x 6Tr]
  elseif popup == 5 then
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )

  -- 1Gr [2SGr x 7Tr]
  elseif popup == 6 then
    i_sgr ( 'sgroup_seven'..clr ) i_sgr ( 'sgroup_seven'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 9 , 1 , 17 , 16 )

  -- 1Gr [2SGr x 8Tr]
  elseif popup == 7 then
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )


  -- 2Gr [2SGr x 2Tr]
  elseif popup == 8 then
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )

  -- 2Gr [2SGr x 3Tr]
  elseif popup == 9 then
    i_sgr ( 'sgroup_three'..clr ) i_sgr ( 'sgroup_three'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 5 , 1 , 9 , 8 )
    i_sgr ( 'sgroup_three'..clr ) i_sgr ( 'sgroup_three'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 5 , 1 , 9 , 8 )

  -- 2Gr [2SGr x 4Tr]
  elseif popup == 10 then
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )

  -- 2Gr [2SGr x 5Tr]
  elseif popup == 11 then
    i_sgr ( 'sgroup_five'..clr ) i_sgr ( 'sgroup_five'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 7 , 1 , 13 , 12 )
    i_sgr ( 'sgroup_five'..clr ) i_sgr ( 'sgroup_five'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 7 , 1 , 13 , 12 )

  -- 2Gr [2SGr x 6Tr]
  elseif popup == 12 then
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )

  -- 2Gr [2SGr x 7Tr]
  elseif popup == 13 then
    i_sgr ( 'sgroup_seven'..clr ) i_sgr ( 'sgroup_seven'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 9 , 1 , 17 , 16 )
    i_sgr ( 'sgroup_seven'..clr ) i_sgr ( 'sgroup_seven'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 9 , 1 , 17 , 16 )

  -- 2Gr [2SGr x 8Tr]
  elseif popup == 14 then
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )

  -- 3Gr [2SGr x 2Tr]
  elseif popup == 15 then
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_three'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )  
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 4 , 1 , 7 , 6 )  
  
  -- 3Gr [2SGr x 4Tr]
  elseif popup == 16 then
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_three'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 6 , 1 , 11 , 10 )

  -- 3Gr [2SGr x 6Tr]
  elseif popup == 17 then
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_three'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 8 , 1 , 15 , 14 )  
  
  -- 3Gr [2SGr x 8Tr]
  elseif popup == 18 then
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_three'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_two'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr ) i_gr ( 'group_one'..clr ) i_sgr_gr( 10 , 1 , 19 , 18 )
  
  -- 1Gr [1AuxTr]
  elseif popup == 19 then
    local song = renoise.song()
    insert_tro( song.selected_track_index + 1, track.a2 )
    i_gr( 'group_one'..clr )
    song:add_track_to_group( song.selected_track_index + 2 , song.selected_track_index + 1 )  
    song:select_next_track()
  end

end

--------------------------------------------------------------------------------
-- SUBGROUPS SELECT (NOT GROUPS)
--------------------------------------------------------------------------------

function  sgr_select ( switch , popup ) -- ( 16 , 16 )

  local clr , C , track = '' , '' , {}
      if switch ==  1 then clr = '_aqua'      C = 'Aqua'
  elseif switch ==  2 then clr = '_black'     C = 'Black'
  elseif switch ==  3 then clr = '_blue'      C = 'Blue'
  elseif switch ==  4 then clr = '_brown'     C = 'Brown'
  elseif switch ==  5 then clr = '_gold'      C = 'Gold'
  elseif switch ==  6 then clr = '_gray'      C = 'Gray'
  elseif switch ==  7 then clr = '_green'     C = 'Green'
  elseif switch ==  8 then clr = '_orange'    C = 'Orange'
  elseif switch ==  9 then clr = '_pale'      C = 'Pale_Pink'
  elseif switch == 10 then clr = '_pink'      C = 'Pink'
  elseif switch == 11 then clr = '_pista'     C = 'Pistachio'
  elseif switch == 12 then clr = '_red'       C = 'Red'
  elseif switch == 13 then clr = '_sky'       C = 'Sky_Blue'
  elseif switch == 14 then clr = '_violet'    C = 'Violet'
  elseif switch == 15 then clr = '_white'     C = 'White'
  elseif switch == 16 then clr = '_yellow'    C = 'Yellow'
  end

  local TWO = _G[ C..'_two' ] -- G_C_two
  track.a2 = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }
  
  -- 1SGr x 2Tr
  if popup == 1 then
    i_sgr ( 'sgroup_two'..clr )

  -- 1SGr x 3Tr
  elseif popup == 2 then
    i_sgr ( 'sgroup_three'..clr )

  -- 1SGr x 4Tr
  elseif popup == 3 then
    i_sgr ( 'sgroup_four'..clr )

  -- 1SGr x 5Tr
  elseif popup == 4 then
    i_sgr ( 'sgroup_five'..clr )

  -- 1SGr x 6Tr
  elseif popup == 5 then
    i_sgr ( 'sgroup_six'..clr )

  -- 1SGr x 7Tr
  elseif popup == 6 then
    i_sgr ( 'sgroup_seven'..clr )

  -- 1SGr x 8Tr
  elseif popup == 7 then
    i_sgr ( 'sgroup_eight'..clr )

  -- 2SGr x 2Tr
  elseif popup == 8 then
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr )

  -- 2SGr x 4Tr
  elseif popup == 9 then
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr )
  
  -- 2SGr x 6Tr
  elseif popup == 10 then
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr )

  -- 2SGr x 8Tr
  elseif popup == 11 then
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr )

  -- 4SGr x 2Tr
  elseif popup == 12 then
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr )
    i_sgr ( 'sgroup_two'..clr ) i_sgr ( 'sgroup_two'..clr )

  -- 4SGr x 4Tr
  elseif popup == 13 then
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr )
    i_sgr ( 'sgroup_four'..clr ) i_sgr ( 'sgroup_four'..clr )

  -- 4SGr x 6Tr
  elseif popup == 14 then
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr )
    i_sgr ( 'sgroup_six'..clr ) i_sgr ( 'sgroup_six'..clr )

  -- 4SGr x 8Tr
  elseif popup == 15 then
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr )
    i_sgr ( 'sgroup_eight'..clr ) i_sgr ( 'sgroup_eight'..clr )

  -- 1Sgr x 1AuxTr
  elseif popup == 16 then
    local song = renoise.song()
    insert_tro( song.selected_track_index + 1, track.a2 )
    i_gr( 'sgroup_one'..clr )
    song:add_track_to_group( song.selected_track_index + 2 , song.selected_track_index + 1 )  
    song:select_next_track()
  end

end



--------------------------------------------------------------------------------
-- OCTAVES SUBGROUPS SELECT (NOT GROUPS)
--------------------------------------------------------------------------------

function  oct_select ( switch , popup ) -- ( 16 , 5 )

    local clr = ''
      if switch ==  1 then clr = '_aqua'
  elseif switch ==  2 then clr = '_black'
  elseif switch ==  3 then clr = '_blue'
  elseif switch ==  4 then clr = '_brown'
  elseif switch ==  5 then clr = '_gold'
  elseif switch ==  6 then clr = '_gray'
  elseif switch ==  7 then clr = '_green'
  elseif switch ==  8 then clr = '_orange'
  elseif switch ==  9 then clr = '_pale'
  elseif switch == 10 then clr = '_pink'
  elseif switch == 11 then clr = '_pista'
  elseif switch == 12 then clr = '_red'
  elseif switch == 13 then clr = '_sky'
  elseif switch == 14 then clr = '_violet'
  elseif switch == 15 then clr = '_white'
  elseif switch == 16 then clr = '_yellow'
  end

  -- 4SGr x 2Tr
  if popup == 1 then
    i_oct ( 'oct_zero_nine'..clr )

  -- 4SGr x 3Tr
  elseif popup == 2 then
    i_oct ( 'oct_zero_three'..clr )

  -- 4SGr x 4Tr
  elseif popup == 3 then
    i_oct ( 'oct_four_six'..clr )

  -- 4SGr x 5Tr
  elseif popup == 4 then
    i_oct ( 'oct_seven_nine'..clr )

  -- 4SGr x 6Tr
  elseif popup == 5 then
    i_oct ( 'oct_three_seven'..clr )
  end

end


--------------------------------------------------------------------------------
-- TRACKS (NOT SUBGROUPS)
--------------------------------------------------------------------------------
 function  tr_select ( switch , popup ) -- ( 16 , 27 )

  local C , track , ito , RNST  = '' , {} , insert_tro , renoise.song().selected_track_index + 1

      if switch ==  1 then C = 'Aqua'
  elseif switch ==  2 then C = 'Black'
  elseif switch ==  3 then C = 'Blue'
  elseif switch ==  4 then C = 'Brown'
  elseif switch ==  5 then C = 'Gold'
  elseif switch ==  6 then C = 'Gray'
  elseif switch ==  7 then C = 'Green'
  elseif switch ==  8 then C = 'Orange'
  elseif switch ==  9 then C = 'Pale_Pink'
  elseif switch == 10 then C = 'Pink'
  elseif switch == 11 then C = 'Pistachio'
  elseif switch == 12 then C = 'Red'
  elseif switch == 13 then C = 'Sky_Blue'
  elseif switch == 14 then C = 'Violet'
  elseif switch == 15 then C = 'White'
  elseif switch == 16 then C = 'Yellow'
    end

  local ONE = _G[C..'_one'] -- G_C_one
  local TWO = _G[C..'_two'] -- G_C_two

  track.one      = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '01 '.. C ..' Track' }
  track.two      = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '02 '.. C ..' Track' }
  track.three    = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '03 '.. C ..' Track' }
  track.four     = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '04 '.. C ..' Track' }
  track.five     = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '05 '.. C ..' Track' }
  track.six      = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '06 '.. C ..' Track' }
  track.seven    = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '07 '.. C ..' Track' }
  track.eight    = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '08 '.. C ..' Track' }
  track.nine     = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '09 '.. C ..' Track' }
  track.ten      = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '10 '.. C ..' Track' }
  track.eleven   = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '11 '.. C ..' Track' }
  track.twelve   = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '12 '.. C ..' Track' }
  track.thirteen = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '13 '.. C ..' Track' }
  track.fourteen = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '14 '.. C ..' Track' }
  track.fifteen  = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '15 '.. C ..' Track' }
  track.sixteen  = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '16 '.. C ..' Track' }
  track.a1       = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }
  track.a2       = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C ..' Track' }

  -- 2Tr
      if popup == 1 then
    ito ( RNST , track.two )   ito ( RNST , track.one )
  
  -- 4Tr
  elseif popup == 2 then
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )
  
  -- 6Tr
  elseif popup == 3 then
    ito ( RNST , track.six )   ito ( RNST , track.five )  ito ( RNST , track.four )
    ito ( RNST , track.three ) ito ( RNST , track.two )   ito ( RNST , track.one )

  -- 8Tr
  elseif popup == 4 then
    ito ( RNST , track.eight ) ito ( RNST , track.seven ) ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )
  
  -- 10Tr
  elseif popup == 5 then
    ito ( RNST , track.ten )   ito ( RNST , track.nine )
    ito ( RNST , track.eight ) ito ( RNST , track.seven ) ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )

  -- 12Tr
  elseif popup == 6 then
    ito ( RNST , track.twelve ) ito ( RNST , track.eleven ) ito ( RNST , track.ten ) ito ( RNST , track.nine )
    ito ( RNST , track.eight )  ito ( RNST , track.seven )  ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )   ito ( RNST , track.three )  ito ( RNST , track.two ) ito ( RNST , track.one )

  -- 14Tr
  elseif popup == 7 then
    ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen )
    ito ( RNST , track.twelve )   ito ( RNST , track.eleven )  ito ( RNST , track.ten ) ito ( RNST , track.nine )
    ito ( RNST , track.eight )    ito ( RNST , track.seven )   ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )     ito ( RNST , track.three )   ito ( RNST , track.two ) ito ( RNST , track.one )

  -- 16Tr
  elseif popup == 8 then
    ito ( RNST , track.sixteen ) ito ( RNST , track.fifteen ) ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen )
    ito ( RNST , track.twelve )  ito ( RNST , track.eleven )  ito ( RNST , track.ten )      ito ( RNST , track.nine )
    ito ( RNST , track.eight )   ito ( RNST , track.seven )   ito ( RNST , track.six )      ito ( RNST , track.five )
    ito ( RNST , track.four )    ito ( RNST , track.three )   ito ( RNST , track.two )      ito ( RNST , track.one )
  
  -- 03Tr - 06Tr
  elseif popup == 9 then
    ito ( RNST , track.six ) ito ( RNST , track.five ) ito ( RNST , track.four ) ito ( RNST , track.three )

  -- 05Tr - 08Tr
  elseif popup == 10 then
    ito ( RNST , track.eight ) ito ( RNST , track.seven ) ito ( RNST , track.six ) ito ( RNST , track.five )

  -- 07Tr - 10Tr
  elseif popup == 11 then
    ito ( RNST , track.ten ) ito ( RNST , track.nine ) ito ( RNST , track.eight ) ito ( RNST , track.seven )

  -- 09Tr - 12Tr
  elseif popup == 12 then
    ito ( RNST , track.twelve )  ito ( RNST , track.eleven ) ito ( RNST , track.ten )   ito ( RNST , track.nine )

  -- 11Tr - 14Tr
  elseif popup == 13 then
    ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen ) ito ( RNST , track.twelve ) ito ( RNST , track.eleven )


  -- 07Tr - 16Tr
  elseif popup == 14 then
    ito ( RNST , track.sixteen )  ito ( RNST , track.fifteen )
    ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen ) ito ( RNST , track.twelve ) ito ( RNST , track.eleven )
    ito ( RNST , track.ten )      ito ( RNST , track.nine )     ito ( RNST , track.eight )  ito ( RNST , track.seven )

  -- 09Tr - 16Tr
  elseif popup == 15 then
    ito ( RNST , track.sixteen ) ito ( RNST , track.fifteen ) ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen )
    ito ( RNST , track.twelve )  ito ( RNST , track.eleven )  ito ( RNST , track.ten )      ito ( RNST , track.nine )

  -- 11Tr - 16Tr
  elseif popup == 16 then
    ito ( RNST , track.sixteen ) ito ( RNST , track.fifteen ) ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen )
    ito ( RNST , track.twelve )  ito ( RNST , track.eleven )

  -- 13Tr - 16Tr
  elseif popup == 17 then
    ito ( RNST , track.sixteen ) ito ( RNST , track.fifteen ) ito ( RNST , track.fourteen ) ito ( RNST , track.thirteen )
  
  -- 15Tr - 16Tr
  elseif popup == 18 then
    ito ( RNST , track.sixteen ) ito ( RNST , track.fifteen )
  
  -- 4Tr + 2AuxTr
  elseif popup == 19 then
    ito ( RNST , track.a2 )    ito ( RNST , track.a1 )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )
  
  -- 6Tr + 2AuxTr
  elseif popup == 20 then
    ito ( RNST , track.a2 )    ito ( RNST , track.a1 )    ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )  

  -- 8Tr + 2AuxTr
  elseif popup == 21 then
    ito ( RNST , track.a2 )    ito ( RNST , track.a1 )
    ito ( RNST , track.eight ) ito ( RNST , track.seven ) ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )
  
  -- 10Tr + 2AuxTr
  elseif popup == 22 then
    ito ( RNST , track.a2 )    ito ( RNST , track.a1 )    ito ( RNST , track.ten ) ito ( RNST , track.nine )
    ito ( RNST , track.eight ) ito ( RNST , track.seven ) ito ( RNST , track.six ) ito ( RNST , track.five )
    ito ( RNST , track.four )  ito ( RNST , track.three ) ito ( RNST , track.two ) ito ( RNST , track.one )
  
  -- 1AuxTr A
  elseif popup == 23 then   
    ito ( RNST , track.a1 )

  -- 1AuxTr B
  elseif popup == 24 then
    ito ( RNST , track.a2 )

  -- 2AuxTr
  elseif popup == 25 then
    ito ( RNST , track.a2 ) ito ( RNST , track.a1 )

  -- 4AuxTr
  elseif popup == 26 then
    ito ( RNST , track.a2 ) ito ( RNST , track.a1 ) ito ( RNST , track.a2 ) ito ( RNST , track.a1 )

  -- 8AuxTr
  elseif popup == 27 then
    ito ( RNST , track.a2 ) ito ( RNST , track.a1 ) ito ( RNST , track.a2 ) ito ( RNST , track.a1 )
    ito ( RNST , track.a2 ) ito ( RNST , track.a1 ) ito ( RNST , track.a2 ) ito ( RNST , track.a1 )
  end

end


--------------------------------------------------------------------------------
-- COMBINED MAIN GROUPS
--------------------------------------------------------------------------------
function mgr_com ( popup ) -- ( 11 )
  local function mgr_com01()
    i_sgr('sgroup_two_white') i_sgr('sgroup_two_gold') i_gr('group_four_pista') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_aqua') i_sgr('sgroup_two_brown') i_gr('group_three_violet') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_pink') i_gr_mgr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_two_orange') i_sgr('sgroup_two_pale') i_gr('group_two_yellow') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_sky') i_sgr('sgroup_two_green') i_gr('group_one_red') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_blue') i_gr_mgr( 8 , 1 , 15 , 14 )
  end
  local function mgr_com02()
    i_sgr('sgroup_four_white') i_sgr('sgroup_four_gold') i_gr('group_four_pista') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_aqua') i_sgr('sgroup_four_brown') i_gr('group_three_violet') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_pink') i_gr_mgr( 12 , 1 , 23 , 22 )
    i_sgr('sgroup_four_orange') i_sgr('sgroup_four_pale') i_gr('group_two_yellow') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_sky') i_sgr('sgroup_four_green') i_gr('group_one_red') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_blue') i_gr_mgr( 12 , 1 , 23 , 22 )
  end
  local function mgr_com03()
    i_sgr('sgroup_six_white') i_sgr('sgroup_six_gold') i_gr('group_four_pista') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_aqua') i_sgr('sgroup_six_brown') i_gr('group_three_violet') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_pink') i_gr_mgr( 16 , 1 , 31 , 30 )
    i_sgr('sgroup_six_orange') i_sgr('sgroup_six_pale') i_gr('group_two_yellow') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_sky') i_sgr('sgroup_six_green') i_gr('group_one_red') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_blue') i_gr_mgr( 16 , 1 , 31 , 30 )    
  end
  local function mgr_com04()
    i_sgr('sgroup_six_white') i_sgr('sgroup_six_gold') i_gr('group_four_pista') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_aqua') i_sgr('sgroup_six_brown') i_gr('group_three_violet') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_pink') i_gr_mgr( 16 , 1 , 31 , 30 )
    i_sgr('sgroup_six_orange') i_sgr('sgroup_six_pale') i_gr('group_two_yellow') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_sky') i_sgr('sgroup_six_green') i_gr('group_one_red') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_blue') i_gr_mgr( 16 , 1 , 31 , 30 )

    i_sgr('sgroup_six_white') i_sgr('sgroup_six_gold') i_gr('group_four_pista') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_aqua') i_sgr('sgroup_six_brown') i_gr('group_three_violet') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_pink') i_gr_mgr( 16 , 1 , 31 , 30 )
    i_sgr('sgroup_six_orange') i_sgr('sgroup_six_pale') i_gr('group_two_yellow') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_sky') i_sgr('sgroup_six_green') i_gr('group_one_red') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_mgr('main_group_blue') i_gr_mgr( 16 , 1 , 31 , 30 ) 
  end
  local function mgr_com05()
    i_sgr('sgroup_eight_white') i_sgr('sgroup_eight_gold') i_gr('group_four_pista') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_aqua') i_sgr('sgroup_eight_brown') i_gr('group_three_violet') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_mgr('main_group_pink') i_gr_mgr( 20 , 1 , 39 , 38 )
    i_sgr('sgroup_eight_orange') i_sgr('sgroup_eight_pale') i_gr('group_two_yellow') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_sky') i_sgr('sgroup_eight_green') i_gr('group_one_red') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_mgr('main_group_blue') i_gr_mgr( 20 , 1 , 39 , 38 )   
  end
  local function mgr_com06()
    i_sgr('sgroup_two_white') i_sgr('sgroup_two_white') i_gr('group_two_white') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_white') i_sgr('sgroup_two_white') i_gr('group_one_white') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_white') i_gr_mgr( 8 , 1 , 15 , 14 )

    i_sgr('sgroup_two_violet') i_sgr('sgroup_two_violet') i_gr('group_two_violet') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_violet') i_sgr('sgroup_two_violet') i_gr('group_one_violet') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_violet') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_orange') i_sgr('sgroup_two_orange') i_gr('group_two_orange') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_orange') i_sgr('sgroup_two_orange') i_gr('group_one_orange') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_orange') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_pink') i_sgr('sgroup_two_pink') i_gr('group_two_pink') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_pink') i_sgr('sgroup_two_pink') i_gr('group_one_pink') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_pink') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_yellow') i_sgr('sgroup_two_yellow') i_gr('group_two_yellow') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_yellow') i_sgr('sgroup_two_yellow') i_gr('group_one_yellow') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_yellow') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_blue') i_sgr('sgroup_two_blue') i_gr('group_two_blue') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_blue') i_sgr('sgroup_two_blue') i_gr('group_one_blue') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_blue') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_green') i_sgr('sgroup_two_green') i_gr('group_two_green') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_green') i_sgr('sgroup_two_green') i_gr('group_one_green') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_green') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_red') i_sgr('sgroup_two_red') i_gr('group_two_red') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_red') i_sgr('sgroup_two_red') i_gr('group_one_red') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_red') i_gr_mgr( 8 , 1 , 15 , 14 )  
  end
  local function mgr_com07()
    i_sgr('sgroup_four_white') i_sgr('sgroup_four_white') i_gr('group_two_white') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_white') i_sgr('sgroup_four_white') i_gr('group_one_white') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_white') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_violet') i_sgr('sgroup_four_violet') i_gr('group_two_violet') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_violet') i_sgr('sgroup_four_violet') i_gr('group_one_violet') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_violet') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_orange') i_sgr('sgroup_four_orange') i_gr('group_two_orange') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_orange') i_sgr('sgroup_four_orange') i_gr('group_one_orange') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_orange') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_pink') i_sgr('sgroup_four_pink') i_gr('group_two_pink') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_pink') i_sgr('sgroup_four_pink') i_gr('group_one_pink') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_pink') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_yellow') i_sgr('sgroup_four_yellow') i_gr('group_two_yellow') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_yellow') i_sgr('sgroup_four_yellow') i_gr('group_one_yellow') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_yellow') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_blue') i_sgr('sgroup_four_blue') i_gr('group_two_blue') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_blue') i_sgr('sgroup_four_blue') i_gr('group_one_blue') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_blue') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_green') i_sgr('sgroup_four_green') i_gr('group_two_green') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_green') i_sgr('sgroup_four_green') i_gr('group_one_green') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_green') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_red') i_sgr('sgroup_four_red') i_gr('group_two_red') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_red') i_sgr('sgroup_four_red') i_gr('group_one_red') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_red') i_gr_mgr( 12 , 1 , 23 , 22 )  
  end
  local function mgr_com08()
    i_sgr('sgroup_two_brown') i_sgr('sgroup_two_brown') i_gr('group_two_brown') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_brown') i_sgr('sgroup_two_brown') i_gr('group_one_brown') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_brown') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_pale') i_sgr('sgroup_two_pale') i_gr('group_two_pale') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_pale') i_sgr('sgroup_two_pale') i_gr('group_one_pale') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_pale') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_aqua') i_sgr('sgroup_two_aqua') i_gr('group_two_aqua') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_aqua') i_sgr('sgroup_two_aqua') i_gr('group_one_aqua') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_aqua') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_black') i_sgr('sgroup_two_black') i_gr('group_two_black') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_black') i_sgr('sgroup_two_black') i_gr('group_one_black') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_black') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_pista') i_sgr('sgroup_two_pista') i_gr('group_two_pista') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_pista') i_sgr('sgroup_two_pista') i_gr('group_one_pista') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_pista') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_gray') i_sgr('sgroup_two_gray') i_gr('group_two_gray') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_gray') i_sgr('sgroup_two_gray') i_gr('group_one_gray') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_gray') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_gold') i_sgr('sgroup_two_gold') i_gr('group_two_gold') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_gold') i_sgr('sgroup_two_gold') i_gr('group_one_gold') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_gold') i_gr_mgr( 8 , 1 , 15 , 14 )
  
    i_sgr('sgroup_two_sky') i_sgr('sgroup_two_sky') i_gr('group_two_sky') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_sky') i_sgr('sgroup_two_sky') i_gr('group_one_sky') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_mgr('main_group_sky') i_gr_mgr( 8 , 1 , 15 , 14 ) 
  end
  local function mgr_com09()
    i_sgr('sgroup_four_brown') i_sgr('sgroup_four_brown') i_gr('group_two_brown') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_brown') i_sgr('sgroup_four_brown') i_gr('group_one_brown') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_brown') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_pale') i_sgr('sgroup_four_pale') i_gr('group_two_pale') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_pale') i_sgr('sgroup_four_pale') i_gr('group_one_pale') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_pale') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_aqua') i_sgr('sgroup_four_aqua') i_gr('group_two_aqua') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_aqua') i_sgr('sgroup_four_aqua') i_gr('group_one_aqua') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_aqua') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_black') i_sgr('sgroup_four_black') i_gr('group_two_black') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_black') i_sgr('sgroup_four_black') i_gr('group_one_black') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_black') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_pista') i_sgr('sgroup_four_pista') i_gr('group_two_pista') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_pista') i_sgr('sgroup_four_pista') i_gr('group_one_pista') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_pista') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_gray') i_sgr('sgroup_four_gray') i_gr('group_two_gray') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_gray') i_sgr('sgroup_four_gray') i_gr('group_one_gray') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_gray') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_gold') i_sgr('sgroup_four_gold') i_gr('group_two_gold') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_gold') i_sgr('sgroup_four_gold') i_gr('group_one_gold') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_gold') i_gr_mgr( 12 , 1 , 23 , 22 )
  
    i_sgr('sgroup_four_sky') i_sgr('sgroup_four_sky') i_gr('group_two_sky') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_sky') i_sgr('sgroup_four_sky') i_gr('group_one_sky') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_mgr('main_group_sky') i_gr_mgr( 12 , 1 , 23 , 22 )  
  end
  
  -- Comb. 2MGr x 2Gr [2SGr x 2Tr]
  if popup == 1 then mgr_com01()

  -- Comb. 2MGr x 2Gr [2SGr x 2Tr] x2  
  elseif popup == 2 then mgr_com01() mgr_com01()
  
  -- Comb. 2MGr x 2Gr [2SGr x 4Tr]
  elseif popup == 3 then mgr_com02()
  
  -- Comb. 2MGr x 2Gr [2SGr x 4Tr] x2
  elseif popup == 4 then mgr_com02() mgr_com02()
  
  -- Comb. 2MGr x 2Gr [2SGr x 6Tr]
  elseif popup == 5 then mgr_com03()

  -- Comb. 2MGr x 2Gr [2SGr x 6Tr] x2
  elseif popup == 6 then mgr_com04()

  -- Comb. 2MGr x 2Gr [2SGr x 8Tr]
  elseif popup == 7 then mgr_com05()
  
  -- Comb. A1.-8MGr x 2Gr [2SGr x 2Tr]
  elseif popup == 8 then mgr_com06()

  -- Comb. A2.-8MGr x 2Gr [2SGr x 4Tr]
  elseif popup == 9 then mgr_com07()

  -- Cmb B1.-8MGr x 2Gr [2SGr x 2Tr]
  elseif popup == 10 then mgr_com08()
  
  -- Cmb B2.-8MGr x 2Gr [2SGr x 4Tr]
  elseif popup == 11 then mgr_com09()
  end

end


--------------------------------------------------------------------------------
-- COMBINED GROUPS
--------------------------------------------------------------------------------
function gr_com ( popup ) -- ( 7 )
  local function gr_com01()
    i_sgr('sgroup_two_orange') i_sgr('sgroup_two_pale') i_gr('group_five_violet') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_white') i_sgr('sgroup_two_gold') i_gr('group_four_pista') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_aqua') i_sgr('sgroup_two_brown') i_gr('group_three_pink') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_sky') i_sgr('sgroup_two_gray') i_gr('group_two_yellow') i_sgr_gr( 4 , 1 , 7 , 6 )
    i_sgr('sgroup_two_blue') i_sgr('sgroup_two_green') i_gr('group_one_red') i_sgr_gr( 4 , 1 , 7 , 6 )
  end
  local function gr_com02()
    i_sgr('sgroup_four_orange') i_sgr('sgroup_four_pale') i_gr('group_five_violet') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_white') i_sgr('sgroup_four_gold') i_gr('group_four_pista') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_aqua') i_sgr('sgroup_four_brown') i_gr('group_three_pink') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_sky') i_sgr('sgroup_four_gray') i_gr('group_two_yellow') i_sgr_gr( 6 , 1 , 11 , 10 )
    i_sgr('sgroup_four_blue') i_sgr('sgroup_four_green') i_gr('group_one_red') i_sgr_gr( 6 , 1 , 11 , 10 )
  end
  local function gr_com03()
    i_sgr('sgroup_six_orange') i_sgr('sgroup_six_pale') i_gr('group_five_violet') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_white') i_sgr('sgroup_six_gold') i_gr('group_four_pista') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_aqua') i_sgr('sgroup_six_brown') i_gr('group_three_pink') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_sky') i_sgr('sgroup_six_gray') i_gr('group_two_yellow') i_sgr_gr( 8 , 1 , 15 , 14 )
    i_sgr('sgroup_six_blue') i_sgr('sgroup_six_green') i_gr('group_one_red') i_sgr_gr( 8 , 1 , 15 , 14 )
  end
  local function gr_com04()
    i_sgr('sgroup_eight_orange') i_sgr('sgroup_eight_pale') i_gr('group_five_violet') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_white') i_sgr('sgroup_eight_gold') i_gr('group_four_pista') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_aqua') i_sgr('sgroup_eight_brown') i_gr('group_three_pink') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_sky') i_sgr('sgroup_eight_gray') i_gr('group_two_yellow') i_sgr_gr( 10 , 1 , 19 , 18 )
    i_sgr('sgroup_eight_blue') i_sgr('sgroup_eight_green') i_gr('group_one_red') i_sgr_gr( 10 , 1 , 19 , 18 ) 
  end
  
  -- Cmb 5Gr [2SGr x 2Tr]
  if popup == 1 then gr_com01()

  -- Cmb 5Gr [2SGr x 2Tr] x2
  elseif popup == 2 then gr_com01() gr_com01()

  -- Cmb 5Gr [2SGr x 4Tr]
  elseif popup == 3 then gr_com02()

  -- Cmb 5Gr [2SGr x 4Tr] x2
  elseif popup == 4 then gr_com02() gr_com02()

  -- Cmb 5Gr [2SGr x 6Tr]
  elseif popup == 5 then gr_com03()
  
  -- Cmb 5Gr [2SGr x 6Tr] x2
  elseif popup == 6 then gr_com03() gr_com03()
  
  -- Cmb 5Gr [2SGr x 8Tr]
  elseif popup == 7 then gr_com04()
  end

end


--------------------------------------------------------------------------------
-- COMBINED MAIN SUBGROUPS
--------------------------------------------------------------------------------
function sgr_com( popup ) -- ( 4 )
  local function sgr_com01()
    i_sgr('sgroup_two_pale') i_sgr('sgroup_two_sky') i_sgr('sgroup_two_black') i_sgr('sgroup_two_pista')
    i_sgr('sgroup_two_gray') i_sgr('sgroup_two_gold') i_sgr('sgroup_two_white') i_sgr('sgroup_two_aqua')
    i_sgr('sgroup_two_brown') i_sgr('sgroup_two_violet') i_sgr('sgroup_two_orange') i_sgr('sgroup_two_pink')
    i_sgr('sgroup_two_yellow') i_sgr('sgroup_two_blue') i_sgr('sgroup_two_green') i_sgr('sgroup_two_red') 
  end
  local function sgr_com02()
    i_sgr('sgroup_four_pale') i_sgr('sgroup_four_sky') i_sgr('sgroup_four_black') i_sgr('sgroup_four_pista')
    i_sgr('sgroup_four_gray') i_sgr('sgroup_four_gold') i_sgr('sgroup_four_white') i_sgr('sgroup_four_aqua')
    i_sgr('sgroup_four_brown') i_sgr('sgroup_four_violet') i_sgr('sgroup_four_orange') i_sgr('sgroup_four_pink')
    i_sgr('sgroup_four_yellow') i_sgr('sgroup_four_blue') i_sgr('sgroup_four_green') i_sgr('sgroup_four_red') 
  end
  local function sgr_com03()
    i_sgr('sgroup_six_pale') i_sgr('sgroup_six_sky') i_sgr('sgroup_six_black') i_sgr('sgroup_six_pista')
    i_sgr('sgroup_six_gray') i_sgr('sgroup_six_gold') i_sgr('sgroup_six_white') i_sgr('sgroup_six_aqua')
    i_sgr('sgroup_six_brown') i_sgr('sgroup_six_violet') i_sgr('sgroup_six_orange') i_sgr('sgroup_six_pink')
    i_sgr('sgroup_six_yellow') i_sgr('sgroup_six_blue') i_sgr('sgroup_six_green') i_sgr('sgroup_six_red') 
  end
  local function sgr_com04()
    i_sgr('sgroup_eight_pale') i_sgr('sgroup_eight_sky') i_sgr('sgroup_eight_black') i_sgr('sgroup_eight_pista')
    i_sgr('sgroup_eight_gray') i_sgr('sgroup_eight_gold') i_sgr('sgroup_eight_white') i_sgr('sgroup_eight_aqua')
    i_sgr('sgroup_eight_brown') i_sgr('sgroup_eight_violet') i_sgr('sgroup_eight_orange') i_sgr('sgroup_eight_pink')
    i_sgr('sgroup_eight_yellow') i_sgr('sgroup_eight_blue') i_sgr('sgroup_eight_green') i_sgr('sgroup_eight_red') 
  end

  -- Cmb 16SGr x 2Tr
  if popup == 1 then sgr_com01()

  -- Cmb 16SGr x 4Tr
  elseif popup == 2 then sgr_com02()
  
  -- Cmb 16SGr x 6Tr
  elseif popup == 3 then sgr_com03()
  
  -- Cmb 16SGr x 8Tr
  elseif popup == 4 then sgr_com04()
  end

end


--------------------------------------------------------------------------------
-- COMBINED TRACKS
--------------------------------------------------------------------------------
function tr_com( popup ) -- ( 4 )
  local track , ito , RNST = {} , insert_tro , renoise.song().selected_track_index + 1
  local C = { 'Aqua' , 'Black' , 'Blue' , 'Brown' , 'Gold' , 'Gray' , 'Green' , 'Orange' , 'Pale_Pink' , 'Pink' , 'Pistachio' , 'Red' , 'Sky_Blue' , 'Violet' , 'White' , 'Yellow' }
  local C2 , ONE , TWO
  for CCount = 1 , 16 do
    C2 = C[ CCount ]
    ONE = _G[ C2..'_one' ] -- G_C_one
    TWO = _G[ C2..'_two' ] -- G_C_two
    track.one   = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '01 '.. C2 ..' Track' }
    track.two   = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '02 '.. C2 ..' Track' }
    track.three = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '03 '.. C2 ..' Track' }
    track.four  = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '04 '.. C2 ..' Track' }
    track.five  = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '05 '.. C2 ..' Track' }
    track.six   = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '06 '.. C2 ..' Track' }
    track.seven = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '07 '.. C2 ..' Track' }
    track.eight = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = F , name = '08 '.. C2 ..' Track' }
    track.a1    = { color = ONE , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C2 ..' Track' }
    track.a2    = { color = TWO , color_blend = 10 , volume_column_visible = T , collapsed = T , name = 'Aux '.. C2 ..' Track' }
    if popup == 1 then
      ito( RNST , track.two) ito( RNST , track.one)
    elseif popup == 2 then
      ito( RNST , track.four) ito( RNST , track.three) ito( RNST , track.two) ito( RNST , track.one)
    elseif popup == 3 then
      ito( RNST , track.six) ito( RNST , track.five) ito( RNST , track.four) ito( RNST , track.three) ito( RNST , track.two) ito( RNST , track.one)
    elseif popup == 4 then
      ito( RNST , track.eight) ito( RNST , track.seven) ito( RNST , track.six) ito( RNST , track.five) ito( RNST , track.four) ito( RNST , track.three) ito( RNST , track.two) ito( RNST , track.one)
    end
  end

end



--------------------------------------------------------------------------------
-- BUTTONS, SWITHES & POPUPS
--------------------------------------------------------------------------------

-- Buttons of Colors -------------------------------------
------------------------------------------------
but_mgr , but_gr , but_sgr , but_oct , but_tr , but_cm , but_tls = {} , {} , {} , {} , {} , {} , {}

  but_mgr.aq = vb:button { active = F , width = 31 , height = 12 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_mgr.bk = vb:button { active = F , width = 30 , height = 12 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_mgr.bl = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_mgr.br = vb:button { active = F , width = 30 , height = 12 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_mgr.gl = vb:button { active = F , width = 30 , height = 12 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_mgr.gy = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_mgr.gr = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_mgr.og = vb:button { active = F , width = 30 , height = 12 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange og
  but_mgr.pl = vb:button { active = F , width = 30 , height = 12 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_mgr.pn = vb:button { active = F , width = 30 , height = 12 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_mgr.ps = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_mgr.rd = vb:button { active = F , width = 30 , height = 12 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_mgr.sk = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_mgr.vl = vb:button { active = F , width = 30 , height = 12 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_mgr.wh = vb:button { active = F , width = 30 , height = 12 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_mgr.yl = vb:button { active = F , width = 31 , height = 12 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl
  
  but_gr.aq = vb:button  { active = F , width = 31 , height = 12 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_gr.bk = vb:button  { active = F , width = 30 , height = 12 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_gr.bl = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_gr.br = vb:button  { active = F , width = 30 , height = 12 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_gr.gl = vb:button  { active = F , width = 30 , height = 12 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_gr.gy = vb:button  { active = F , width = 30 , height = 12 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_gr.gr = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_gr.og = vb:button  { active = F , width = 30 , height = 12 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange og
  but_gr.pl = vb:button  { active = F , width = 30 , height = 12 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_gr.pn = vb:button  { active = F , width = 30 , height = 12 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_gr.ps = vb:button  { active = F , width = 30 , height = 12 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_gr.rd = vb:button  { active = F , width = 30 , height = 12 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_gr.sk = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_gr.vl = vb:button  { active = F , width = 30 , height = 12 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_gr.wh = vb:button  { active = F , width = 30 , height = 12 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_gr.yl = vb:button  { active = F , width = 31 , height = 12 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl
  
  but_sgr.aq = vb:button { active = F , width = 31 , height = 12 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_sgr.bk = vb:button { active = F , width = 30 , height = 12 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_sgr.bl = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_sgr.br = vb:button { active = F , width = 30 , height = 12 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_sgr.gl = vb:button { active = F , width = 30 , height = 12 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_sgr.gy = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_sgr.gr = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_sgr.og = vb:button { active = F , width = 30 , height = 12 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange og
  but_sgr.pl = vb:button { active = F , width = 30 , height = 12 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_sgr.pn = vb:button { active = F , width = 30 , height = 12 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_sgr.ps = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_sgr.rd = vb:button { active = F , width = 30 , height = 12 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_sgr.sk = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_sgr.vl = vb:button { active = F , width = 30 , height = 12 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_sgr.wh = vb:button { active = F , width = 30 , height = 12 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_sgr.yl = vb:button { active = F , width = 31 , height = 12 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl

  but_oct.aq = vb:button { active = F , width = 31 , height = 12 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_oct.bk = vb:button { active = F , width = 30 , height = 12 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_oct.bl = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_oct.br = vb:button { active = F , width = 30 , height = 12 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_oct.gl = vb:button { active = F , width = 30 , height = 12 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_oct.gy = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_oct.gr = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_oct.og = vb:button { active = F , width = 30 , height = 12 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange og
  but_oct.pl = vb:button { active = F , width = 30 , height = 12 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_oct.pn = vb:button { active = F , width = 30 , height = 12 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_oct.ps = vb:button { active = F , width = 30 , height = 12 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_oct.rd = vb:button { active = F , width = 30 , height = 12 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_oct.sk = vb:button { active = F , width = 30 , height = 12 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_oct.vl = vb:button { active = F , width = 30 , height = 12 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_oct.wh = vb:button { active = F , width = 30 , height = 12 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_oct.yl = vb:button { active = F , width = 31 , height = 12 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl

  but_tr.aq = vb:button  { active = F , width = 31 , height = 12 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_tr.bk = vb:button  { active = F , width = 30 , height = 12 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_tr.bl = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_tr.br = vb:button  { active = F , width = 30 , height = 12 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_tr.gl = vb:button  { active = F , width = 30 , height = 12 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_tr.gy = vb:button  { active = F , width = 30 , height = 12 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_tr.gr = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_tr.og = vb:button  { active = F , width = 30 , height = 12 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange og
  but_tr.pl = vb:button  { active = F , width = 30 , height = 12 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_tr.pn = vb:button  { active = F , width = 30 , height = 12 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_tr.ps = vb:button  { active = F , width = 30 , height = 12 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_tr.rd = vb:button  { active = F , width = 30 , height = 12 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_tr.sk = vb:button  { active = F , width = 30 , height = 12 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_tr.vl = vb:button  { active = F , width = 30 , height = 12 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_tr.wh = vb:button  { active = F , width = 30 , height = 12 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_tr.yl = vb:button  { active = F , width = 31 , height = 12 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl

  but_cm.aq = vb:button  { active = F , width = 10 , height = 18 , color = { 0x1A,0x9A,0x8D } , tooltip = 'Aqua Color' }      --  1 Aqua aq
  but_cm.bk = vb:button  { active = F , width = 10 , height = 18 , color = { 0x24,0x24,0x24 } , tooltip = 'Black Color' }     --  2 Black bk
  but_cm.bl = vb:button  { active = F , width = 10 , height = 18 , color = { 0x00,0x44,0xFF } , tooltip = 'Blue Color' }      --  3 Blue bl
  but_cm.br = vb:button  { active = F , width = 10 , height = 18 , color = { 0x99,0x4D,0x00 } , tooltip = 'Brown Color' }     --  4 Brown br
  but_cm.gl = vb:button  { active = F , width = 10 , height = 18 , color = { 0xEF,0xA5,0x13 } , tooltip = 'Gold Color' }      --  5 Gold gl
  but_cm.gy = vb:button  { active = F , width = 10 , height = 18 , color = { 0x70,0x70,0x70 } , tooltip = 'Gray Color' }      --  6 Gray gy
  but_cm.gr = vb:button  { active = F , width = 10 , height = 18 , color = { 0x00,0x99,0x19 } , tooltip = 'Green Color' }     --  7 Green gr
  but_cm.og = vb:button  { active = F , width = 10 , height = 18 , color = { 0xEE,0x70,0x00 } , tooltip = 'Orange Color' }    --  8 Orange or
  but_cm.pl = vb:button  { active = F , width = 10 , height = 18 , color = { 0xE4,0xB1,0xC9 } , tooltip = 'Pale Pink Color' } --  9 Pale_Pink pl
  but_cm.pn = vb:button  { active = F , width = 10 , height = 18 , color = { 0xE0,0x00,0x90 } , tooltip = 'Pink Color' }      -- 10 Pink pn
  but_cm.ps = vb:button  { active = F , width = 10 , height = 18 , color = { 0x70,0xEF,0x85 } , tooltip = 'Pistachio Color' } -- 11 Pistachio ps
  but_cm.rd = vb:button  { active = F , width = 10 , height = 18 , color = { 0xCC,0x00,0x00 } , tooltip = 'Red Color' }       -- 12 Red rd
  but_cm.sk = vb:button  { active = F , width = 10 , height = 18 , color = { 0x00,0xDD,0xEE } , tooltip = 'Sky Blue Color' }  -- 13 Sky Blue sk
  but_cm.vl = vb:button  { active = F , width = 10 , height = 18 , color = { 0x81,0x00,0xEB } , tooltip = 'Violet Color' }    -- 14 Violet vl
  but_cm.wh = vb:button  { active = F , width = 10 , height = 18 , color = { 0xF1,0xF1,0xF1 } , tooltip = 'White Color' }     -- 15 White wh
  but_cm.yl = vb:button  { active = F , width = 10 , height = 18 , color = { 0xD1,0xD1,0x00 } , tooltip = 'Yellow Color' }    -- 16 Yellow yl



-- Switches (5 + 5) ----------------------------
------------------------------------------------
  -- 'Aq' , 'Bk' , 'Bl' , 'Br' , 'Gl' , 'Gy' , 'Gr' , 'Or' , 'Pl' , 'Pn' , 'Ps' , 'Rd' , 'Sk' , 'Vl' , 'Wh' , 'Yl'
  swi_cl_mgr   = vb:switch { items = { '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' } , id = 'mgr_switch_cl' , width = 484 , height = 12 , value = 8 }
  swi_cl_gr    = vb:switch { items = { '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' } , id = 'gr_switch_cl'  , width = 484 , height = 12 , value = 8 }
  swi_cl_sgr   = vb:switch { items = { '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' } , id = 'sgr_switch_cl' , width = 484 , height = 12 , value = 8 }
  swi_cl_oct   = vb:switch { items = { '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' } , id = 'oct_switch_cl' , width = 484 , height = 12 , value = 8 }
  swi_cl_tr    = vb:switch { items = { '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' , '' } , id = 'tr_switch_cl'  , width = 484 , height = 12 , value = 8 }

  swi_cl_menu  = vb:switch { items = { '⇱ Compact', 'Main Groups', 'Groups', 'SubGroups', 'Tracks', 'Combined...' }, id = 'main_switch', tooltip = '⇱ Compact   [CTRL + HOME]\nPrincipal Options   [F1] [F2] [F3] [F4] [F5]',
                             notifier = function(new_index) show_tab(new_index) end, width = 460, height = 24, value = 2  } -- show_tab(2)

  swi_cl_sgrmenu = vb:switch { items = { 'SubGroups', 'Octaves' }, id = 'subgroup_switch', tooltip = 'SubGroups  [F3]\nOctaves  [SHIFT + F3]',
                               notifier = function(new_index) show_sgrtab(new_index) end, width = 180, height = 18, value = 1 } -- show_sgrtab(1)

  swi_cl_smenu = vb:switch { items = { '...Main Groups', '...Groups', '...SubGroups', '...Tracks' }, id = 'submain_switch', tooltip = 'Combined SubOptions\n[F5] [F6] [F7] [F8]',
                             notifier = function(new_index) show_subtab(new_index) end, width = 360, height = 20, value = 1 } -- show_subtab(1)

  swi_cl_hmenu = vb:switch { items = { '⇱', '☲K', '?', '⚒' }, id = 'help_switch', tooltip = '⇱ Close below  [CTRL + END]\n☲K Key Commands  [CTRL + PRIOR]\n? About  [CTRL + NEXT]\n⚒ Advanced Tools [CTRL + INS]',
                             notifier = function(new_index) show_hlptab(new_index) end, width = 92, height = 24, value = 1 } -- show_hlptab(1)

  swi_cl_tmenu = vb:switch { items = {'1', '2', '3', '4', '5', '6', '7', '8', '9', '0'}, id = 'tools_switch', tooltip = 'Advanced Tools Area \n[CTRL + 1,2...9,0]\n&\nSPNO with SGr Octaves\n[CTRL+SHIFT + 2]',
                           notifier = function(new_index) show_tlstab(new_index) end, width = 300, height = 20, value = 1 }  -- show_tlstab(1)

-- Popups (x9) ---------------------------------
------------------------------------------------
mgroup = vb:popup { id = 'mgr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  1 Main Group x 2 Groups [2 SubGroups x 2 Tracks] ............................. Total = 15' ,
                                                                     ' 02)  1 Main Group x 2 Groups [2 SubGroups x 3 Tracks] ............................. Total = 19' ,
                                                                     ' 03)  1 Main Group x 2 Groups [2 SubGroups x 4 Tracks] ............................. Total = 23' ,
                                                                     ' 04)  1 Main Group x 2 Groups [2 SubGroups x 5 Tracks] ............................. Total = 27' ,
                                                                     ' 05)  1 Main Group x 2 Groups [2 SubGroups x 6 Tracks] ............................. Total = 31' ,
                                                                     ' 06)  1 Main Group x 2 Groups [2 SubGroups x 7 Tracks] ............................. Total = 35' ,
                                                                     ' 07)  1 Main Group x 2 Groups [2 SubGroups x 8 Tracks] ............................. Total = 39' ,
                                                                     ' 08)  1 Main Group [1 Aux Track] ................................................................... Total = 02' ,
                                                                     }
                  }

group  = vb:popup { id = 'gr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  1 Groups [2 SubGroups x 2 Tracks] ....................................................... Total = 7' ,
                                                                     ' 02)  1 Groups [2 SubGroups x 3 Tracks] ....................................................... Total = 9' ,
                                                                     ' 03)  1 Groups [2 SubGroups x 4 Tracks] ....................................................... Total = 11' ,
                                                                     ' 04)  1 Groups [2 SubGroups x 5 Tracks] ....................................................... Total = 13' ,
                                                                     ' 05)  1 Groups [2 SubGroups x 6 Tracks] ....................................................... Total = 15' ,
                                                                     ' 06)  1 Groups [2 SubGroups x 7 Tracks] ....................................................... Total = 17' ,
                                                                     ' 07)  1 Groups [2 SubGroups x 8 Tracks] ....................................................... Total = 19' ,
                                                                     ' 08)  2 Groups [2 SubGroups x 2 Tracks] ....................................................... Total = 14' ,
                                                                     ' 09)  2 Groups [2 SubGroups x 3 Tracks] ....................................................... Total = 18' ,
                                                                     ' 10)  2 Groups [2 SubGroups x 4 Tracks] ....................................................... Total = 22' ,
                                                                     ' 11)  2 Groups [2 SubGroups x 5 Tracks] ....................................................... Total = 26' ,
                                                                     ' 12)  2 Groups [2 SubGroups x 6 Tracks] ....................................................... Total = 30' ,
                                                                     ' 13)  2 Groups [2 SubGroups x 7 Tracks] ....................................................... Total = 34' ,
                                                                     ' 14)  2 Groups [2 SubGroups x 8 Tracks] ....................................................... Total = 38' ,
                                                                     ' 15)  2 Groups [3 SubGroups x 2 Tracks] ....................................................... Total = 21' ,
                                                                     ' 16)  2 Groups [3 SubGroups x 4 Tracks] ....................................................... Total = 33' ,
                                                                     ' 17)  2 Groups [3 SubGroups x 6 Tracks] ....................................................... Total = 45' ,
                                                                     ' 18)  2 Groups [3 SubGroups x 8 Tracks] ....................................................... Total = 58' ,
                                                                     ' 19)  1 Group [1 Aux Track] ............................................................................ Total = 02' ,
                                                                     }
                  }

sgroup = vb:popup { id = 'sgr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  [1 SubGroups x 2 Tracks] ...................................................................... Total = 03' ,
                                                                     ' 02)  [1 SubGroups x 3 Tracks] ...................................................................... Total = 04' ,
                                                                     ' 03)  [1 SubGroups x 4 Tracks] ...................................................................... Total = 05' ,
                                                                     ' 04)  [1 SubGroups x 5 Tracks] ...................................................................... Total = 06' ,
                                                                     ' 05)  [1 SubGroups x 6 Tracks] ...................................................................... Total = 07' ,
                                                                     ' 06)  [1 SubGroups x 7 Tracks] ...................................................................... Total = 08' ,
                                                                     ' 07)  [1 SubGroups x 8 Tracks] ...................................................................... Total = 09' ,
                                                                     ' 08)  [2 SubGroups x 2 Tracks] ...................................................................... Total = 06' ,
                                                                     ' 09)  [2 SubGroups x 4 Tracks] ...................................................................... Total = 10' ,
                                                                     ' 10)  [2 SubGroups x 6 Tracks] ...................................................................... Total = 14' ,
                                                                     ' 11)  [2 SubGroups x 8 Tracks] ...................................................................... Total = 18' ,
                                                                     ' 12)  [4 SubGroups x 2 Tracks] ...................................................................... Total = 12' ,
                                                                     ' 13)  [4 SubGroups x 4 Tracks] ...................................................................... Total = 20' ,
                                                                     ' 14)  [4 SubGroups x 6 Tracks] ...................................................................... Total = 28' ,
                                                                     ' 15)  [4 SubGroups x 8 Tracks] ...................................................................... Total = 36' ,
                                                                     ' 14)  [1 SubGroup x1 Aux Track] ................................................................... Total = 02' ,
                                                                     }
                  }

octave = vb:popup { id = 'oct_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  1 Octaves SubGroup [0 to 9 Octaves] (120 Note Columns) ............... Total = 11' ,
                                                                     ' 02)  1 Octaves SubGroup [0 to 3 Octaves] (Low Range) ........................... Total = 05' ,
                                                                     ' 03)  1 Octaves SubGroup [4 to 6 Octaves] (Medium Range I) ................... Total = 04' ,
                                                                     ' 04)  1 Octaves SubGroup [7 to 9 Octaves] (High Range) ........................... Total = 04' ,
                                                                     ' 05)  1 Octaves SubGroup [3 to 7 Octaves] (Medium Range II) .................. Total = 08' ,
                                   }
                  }

track  = vb:popup { id = 'tr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  2 Tracks .................................................................................................. Total = 02' ,
                                                                     ' 02)  4 Tracks .................................................................................................. Total = 04' ,
                                                                     ' 03)  6 Tracks .................................................................................................. Total = 06' ,
                                                                     ' 04)  8 Tracks .................................................................................................. Total = 08' ,
                                                                     ' 05)  10 Tracks ................................................................................................ Total = 10' ,
                                                                     ' 06)  12 Tracks ................................................................................................ Total = 12' ,
                                                                     ' 07)  14 Tracks ................................................................................................ Total = 14' ,
                                                                     ' 08)  16 Tracks ................................................................................................ Total = 16' ,
                                                                     ' 09)  03 to 06 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 10)  05 to 08 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 11)  07 to 10 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 12)  09 to 12 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 13)  11 to 14 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 14)  07 to 16 Tracks ....................................................................................... Total = 10' ,
                                                                     ' 15)  09 to 16 Tracks ....................................................................................... Total = 08' ,
                                                                     ' 16)  11 to 16 Tracks ....................................................................................... Total = 06' ,
                                                                     ' 17)  13 to 16 Tracks ....................................................................................... Total = 04' ,
                                                                     ' 18)  15 to 16 Tracks ....................................................................................... Total = 02' ,
                                                                     ' 19)  4 Tracks + 2 Aux Tracks .......................................................................... Total = 06' ,
                                                                     ' 20)  6 Tracks + 2 Aux Tracks .......................................................................... Total = 08' ,
                                                                     ' 21)  8 Tracks + 2 Aux Tracks .......................................................................... Total = 10' ,
                                                                     ' 22)  10 Tracks + 2 Aux Tracks ........................................................................ Total = 12' ,
                                                                     ' 23)  1 Aux Track A (collapsed, light) ............................................................... Total = 01' ,
                                                                     ' 24)  1 Aux Track B (collapsed, dark) .............................................................. Total = 01' ,
                                                                     ' 25)  2 Aux Tracks ........................................................................................... Total = 02' ,
                                                                     ' 26)  4 Aux Tracks ........................................................................................... Total = 04' ,
                                                                     ' 27)  8 Aux Tracks ........................................................................................... Total = 08' ,
                                                                     }
                  }

mgrcom = vb:popup { id = 'cmgr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  Cmb 2 Main Groups x 2 Groups [2 SGr x 2 Tr] ................................ Total = 30' ,
                                                                     ' 02)  Cmb 2 Main Groups x 2 Groups [2 SGr x 2 Tr] x2 ........................... Total = 60' ,
                                                                     ' 03)  Cmb 2 Main Groups x 2 Groups [2 SGr x 4 Tr] ................................ Total = 46' ,
                                                                     ' 04)  Cmb 2 Main Groups x 2 Groups [2 SGr x 4 Tr] x2 ........................... Total = 92' ,
                                                                     ' 05)  Cmb 2 Main Groups x 2 Groups [2 SGr x 6 Tr] ................................ Total = 62' ,
                                                                     ' 06)  Cmb 2 Main Groups x 2 Groups [2 SGr x 6 Tr] x2  ⚠ ...................... Total = 124' ,
                                                                     ' 07)  Cmb 2 Main Groups x 2 Groups [2 SGr x 8 Tr] ................................ Total = 78' ,
                                                                     ' 08)  Cmb A1- 8 Main Groups x 2 Groups [2 SGr x 2 Tr]  ⚠ .................... Total = 120' ,
                                                                     ' 09)  Cmb A2- 8 Main Groups x 2 Groups [2 SGr x 4 Tr]  ⚠⚠ ................. Total = 184' ,
                                                                     ' 10)  Cmb B1- 8 Main Groups x 2 Groups [2 SGr x 2 Tr]  ⚠ .................... Total = 120' ,
                                                                     ' 11)  Cmb B2- 8 Main Groups x 2 Groups [2 SGr x 4 Tr]  ⚠⚠ ................. Total = 184' ,
                                                                     }
                  }

grcom =  vb:popup { id = 'cgr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  Cmb 5 Groups [2 SubGroups x 2 Tracks] ......................................... Total = 35' ,
                                                                     ' 02)  Cmb 5 Groups [2 SubGroups x 2 Tracks] x2 .................................... Total = 70' ,
                                                                     ' 03)  Cmb 5 Groups [2 SubGroups x 4 Tracks] ......................................... Total = 55' ,
                                                                     ' 04)  Cmb 5 Groups [2 SubGroups x 4 Tracks] x2 ⚠ ................................ Total = 110' ,
                                                                     ' 05)  Cmb 5 Groups [2 SubGroups x 6 Tracks] ......................................... Total = 75' ,
                                                                     ' 06)  Cmb 5 Groups [2 SubGroups x 6 Tracks] x2 ⚠ ................................ Total = 150' ,
                                                                     ' 07)  Cmb 5 Groups [2 SubGroups x 8 Tracks] ......................................... Total = 95' ,
                                                                     }
                  }

sgrcom = vb:popup { id = 'csgr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  Cmb 16 SubGroups x 2 Tracks ......................................................... Total = 48' ,
                                                                     ' 02)  Cmb 16 SubGroups x 4 Tracks ......................................................... Total = 80' ,
                                                                     ' 03)  Cmb 16 SubGroups x 6 Tracks ⚠ ..................................................... Total = 112' ,
                                                                     ' 04)  Cmb 16 SubGroups x 8 Tracks ⚠ ..................................................... Total = 144' ,
                                                                     }
                  }

trcom =  vb:popup { id = 'ctr_popup', width = '100%' , height = 24, value = 1, items = {
                                                                     ' 01)  Cmb 16 x 2 Tracks ............................................................................ Total = 32' ,
                                                                     ' 02)  Cmb 16 x 4 Tracks ............................................................................ Total = 64' ,
                                                                     ' 03)  Cmb 16 x 6 Tracks ............................................................................ Total = 96' ,
                                                                     ' 04)  Cmb 16 x 8 Tracks ⚠ ........................................................................ Total = 128' ,
                                                                     }
                  }


-- Insert Buttons ( 5 + 4 ) --------------------
------------------------------------------------
--Insert MGr
function insert_01()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    mgr_select ( swi_cl_mgr.value , mgroup.value )
    renoise.app():show_status( "GT16-Colors:  your selected Main Group has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

--Insert Gr
function insert_02()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    gr_select ( swi_cl_gr.value , group.value )
    renoise.app():show_status( "GT16-Colors:  your selected Group/s has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

--Insert SGr
function insert_03()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    sgr_select ( swi_cl_sgr.value , sgroup.value )
    renoise.app():show_status( "GT16-Colors:  your selected SubGroups has been inserted in Pattern Editor." )
  else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

--Insert Oct
function insert_oct()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    oct_select ( swi_cl_oct.value , octave.value )
    renoise.app():show_status( "GT16-Colors:  your selected Octaves SubGroup has been inserted in Pattern Editor." )
  else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

--Insert Tr
function insert_04()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then 
    tr_select ( swi_cl_tr.value , track.value )
    renoise.app():show_status( "GT16-Colors:  your selected Track/s has been inserted in Pattern Editor." )
  else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

  
--Combined...
--Insert Cmb MGr
function insert_05()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    mgr_com ( mgrcom.value )
    renoise.app():show_status( "GT16-Colors:  your selected Combined Main Groups has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end

--Insert Cmb Gr
function insert_06()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    gr_com ( grcom.value )
    renoise.app():show_status( "GT16-Colors:  your selected Combined Groups has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end
  
--Insert Cmb SGr
function insert_07()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    sgr_com ( sgrcom.value )
    renoise.app():show_status( "GT16-Colors:  your selected Combined SubGroups has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end
  
--Insert Cmb Tr
function insert_08()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tr_com( trcom.value )
    renoise.app():show_status( "GT16-Colors:  your selected Combined Tracks has been inserted in Pattern Editor." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, select before a Track or Group in Pattern Editor or Mixer!!!" )
  end
end


-- Lower Buttons ( x14 ) ------------------------
-------------------------------------------------
--Swap, Undo/Redo, NavTracks, Del & First/Last
function navt_swap_left()
  local song = renoise.song()
  --print (song.selected_track_index , song.sequencer_track_count - song.sequencer_track_count + 1)
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER and song.selected_track_index > 1) then
      song:swap_tracks_at(song.selected_track_index, song.selected_track_index - 1)
      song:select_previous_track()
    renoise.app():show_status( "GT16-Colors:  your selected Track has been swaped to left." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, for Swap select before a Track in Pattern Editor or Mixer!!!" )
  end
end
function navt_swap_right()
  local song = renoise.song()
  --print (song.selected_track_index , song.sequencer_track_count)
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER and song.selected_track_index < song.sequencer_track_count) then
      song:swap_tracks_at(song.selected_track_index, song.selected_track_index + 1)
      song:select_next_track()
    renoise.app():show_status( "GT16-Colors:  your selected Track has been swaped to right." )
    else renoise.app():show_status( "⚠ GT16-Colors:  please, for Swap select before a Track in Pattern Editor or Mixer!!!" )
  end    
end
---
function navt_coll_gr( A )
  local song = renoise.song()
  local selected_track = song.tracks[ song.selected_track_index ]
  if ( selected_track.type == renoise.Track.TRACK_TYPE_GROUP ) then
    for i = 1, #selected_track.members do
      A = selected_track.members[ i ]
          if ( A.collapsed == T ) then A.collapsed = F -- False is expanded
        renoise.app():show_status( "GT16-Colors:  selected Group expanded." )
      elseif ( A.collapsed == F ) then A.collapsed = T -- True is collapsed
          renoise.app():show_status( "GT16-Colors:  selected Group collapsed." )
      end
    end
  end
  if ( selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) or
     ( selected_track.type == renoise.Track.TRACK_TYPE_MASTER ) or
   ( selected_track.type == renoise.Track.TRACK_TYPE_SEND ) then
    if selected_track.collapsed == T then song.tracks[song.selected_track_index].collapsed = F
    if ( selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) then
      renoise.app():show_status( "GT16-Colors:  selected Track expanded." )
      end
    if ( selected_track.type == renoise.Track.TRACK_TYPE_MASTER ) then
      renoise.app():show_status( "GT16-Colors:  selected Master expanded." )
      end
    if ( selected_track.type == renoise.Track.TRACK_TYPE_SEND ) then
      renoise.app():show_status( "GT16-Colors:  selected Send expanded." )
    end
    elseif selected_track.collapsed == F then song.tracks[song.selected_track_index].collapsed = T
    if ( selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) then
      renoise.app():show_status( "GT16-Colors:  selected Track colapsed." )
    end
    if ( selected_track.type == renoise.Track.TRACK_TYPE_MASTER ) then
      renoise.app():show_status( "GT16-Colors:  selected Master colapsed." )
    end
    if ( selected_track.type == renoise.Track.TRACK_TYPE_SEND ) then
      renoise.app():show_status( "GT16-Colors:  selected Send colapsed." )
    end
    end
  end  
end
---
function navt_on_off( A )
  local song = renoise.song()
  if ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) or 
     ( song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP ) or
     ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEND ) then
    A = song.tracks[song.selected_track_index].mute_state
  end
  if A == 1 then song.tracks[song.selected_track_index]:mute()
    if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) then
      renoise.app():show_status( "GT16-Colors:  selected Track Off." )
  end
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
      renoise.app():show_status( "GT16-Colors:  selected Group Off." )
  end
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEND) then
      renoise.app():show_status( "GT16-Colors:  selected Send Off." )
  end
  elseif A == 2 then song.tracks[song.selected_track_index]:unmute()
    if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) then
      renoise.app():show_status( "GT16-Colors:  selected Track Play." )
  end
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
      renoise.app():show_status( "GT16-Colors:  selected Group Play." )
  end
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEND) then
      renoise.app():show_status( "GT16-Colors:  selected Send Play." )
  end
  else 
  renoise.app():show_status( "GT16-Colors:  please, for Play/Off select before a Track/Group/Send in Pattern Editor or Mixer!!!" )
  end
end
---
function navt_undo()
  local song = renoise.song()
  song:undo()
end
function navt_redo()
  local song = renoise.song()
  song:redo()
end
---
function navt_01()
  local song = renoise.song()
  if song.selected_track_index > 2 then
    song:select_previous_track() song:select_previous_track()
  renoise.app():show_status( "GT16-Colors: x2 previous Track/Group selected." )
  end  
end
function navt_02()
  local song = renoise.song()
  if song.selected_track_index > 1 then
    song:select_previous_track()
  renoise.app():show_status( "GT16-Colors:  previous Track/Group selected." )
  end
end
function navt_03()
  local song = renoise.song()
  if song.selected_track_index < song.sequencer_track_count - 1 then
    song:select_next_track() song:select_next_track()
  renoise.app():show_status( "GT16-Colors:  x2 next Track/Group selected." )
  end
end
function navt_04()
  local song = renoise.song()
  if song.selected_track_index < song.sequencer_track_count then
    song:select_next_track()
  renoise.app():show_status( "GT16-Colors:  next Track/Group selected." )
  end
end
---
function navt_del()
  local song = renoise.song()
  if ( song.sequencer_track_count == 1 ) then
  elseif ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) or
         ( song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP ) then
    song:delete_track_at( song.selected_track_index )
    renoise.app():show_status( "GT16-Colors:  selected Track/Group deleted." )
  end     
  if ( song.sequencer_track_count + song.send_track_count  == 1 ) then
  elseif ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEND ) then
    song:delete_track_at( song.selected_track_index )
    renoise.app():show_status( "GT16-Colors:  selected send deleted." )
  end
  if ( song.selected_track.type == renoise.Track.TRACK_TYPE_MASTER ) then
    renoise.app():show_status( "GT16-Colors:  Master is not deletable! Please, for delete select before a Track/Group/Send in Pattern Editor or Mixer!!!" )
  end 
  if ( song.selected_track_index == 1 ) and ( song.sequencer_track_count == 1 ) then
  renoise.app():show_status( "GT16-Colors:  only a Track or Group in Pattern Editor. Include more Tracks and delete after!" )      
  end
end
---
function navt_rem( A , B )
  local song = renoise.song()
  A = song.sequencer_track_count
  B = song.send_track_count
  for A = 2 , song.sequencer_track_count do
    if ( ( song.sequencer_track_count <= 99 ) and ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) or ( song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP ) ) then
      song:delete_track_at( song.selected_track_index ) ---- LIMIT = 99 ---------|***
      renoise.app():show_status( "GT16-Colors:  all Groups & Tracks removed inside Pattern Editor, least the first. Start again!" )
    end
  end
  for B = 1, song.sequencer_track_count + song.send_track_count do
    if ( ( song.send_track_count <= 99 ) and ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEND ) ) then
      song:delete_track_at( song.selected_track_index ) ---- LIMIT = 99 ---------|***
    end  
  end
  if A == 1 and ( song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) or ( song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP ) then
    renoise.app():show_status( "GT16-Colors:  only a Track or Group in Pattern Editor. Include more Tracks and remove after!" )
  end
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_MASTER) then
    renoise.app():show_status( "GT16-Colors:  master is not deletable! Please, for delete select before a Track/Group/Send in Pattern Editor or Mixer!!!" )
  end 
end
---
function navt_first()
  local song = renoise.song()
  song.selected_track_index = song.sequencer_track_count - song.sequencer_track_count + 1 
  renoise.app():show_status( "GT16-Colors:  jumped to first Track/Group." )
end
function navt_last()
  local song = renoise.song()
  song.selected_track_index = song.sequencer_track_count
  renoise.app():show_status( "GT16-Colors:  jumped to last Track/Group." )
end


-- Show Index in real time ( x1 for 3 + 2 ) ---------
-------------------------------------------------
tracks_ics = function()
  local track_index = renoise.song().selected_track_index
  vb.views["tr_index"].text = ( "I:%s" ):format( track_index )
  local track_count = renoise.song().sequencer_track_count
  vb.views["tr_count"].text = ( "C:%d" ):format( track_count )
  
      if renoise.song().sequencer_track_count <= 48 then
    vb.views["bar_count"].color = { 0x00,0xFF,0x2A } --green
  elseif renoise.song().sequencer_track_count >= 49 and renoise.song().sequencer_track_count <= 96 then
    vb.views["bar_count"].color = { 0xFF,0x80,0x00 } --orange
  elseif renoise.song().sequencer_track_count >= 97 then
    vb.views["bar_count"].color = { 0xFF,0x00,0x00 } --red
  end
 
  local track_send = renoise.song().send_track_count
  vb.views["tr_send"].text = ( "S:%d" ):format( track_send )

  --vb.views['nav_track'].min = 0
  --vb.views['nav_track'].max = renoise.song().sequencer_track_count + 1 + renoise.song().send_track_count
  --vb.views['nav_track'].value = renoise.song().selected_track_index
  --vb.views["nav_track"].notifier = function(value) renoise.song().selected_track_index = value end

  vb.views["index_value"].text = ( "%s " ):format( renoise.song().selected_track_index )  
  vb.views["col_value"].text = ( " %s" ):format( renoise.song().tracks[ renoise.song().selected_track_index ].visible_note_columns )
end

function ini_tracks()
  renoise.song().selected_track_index_observable:add_notifier(tracks_ics)
end
renoise.tool().app_new_document_observable:add_notifier(ini_tracks) -- To initialice New Start Renoise



-- Process Buttons for Advanced Tools (x10) -----
-------------------------------------------------

function process_03()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_03 ()
  end
end
function process_04()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_04 ()
  end
end
function process_05()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_05 ()
  end
end
function process_06()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_06 ()
  end
end
function process_07()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_07 ()
  end
end
function process_08()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_08 ()
  end
end
function process_09()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_09 ()
  end
end
function process_10()
  local song = renoise.song()
  if (song.selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER) or (song.selected_track.type == renoise.Track.TRACK_TYPE_GROUP) then
    tool_10 ()
  end
end
  
--------------------------------------------------------------------------------
-- SCHEMES, & TEXT
--------------------------------------------------------------------------------
-- Schemes -------------------------------------
------------------------------------------------
sch = {}
  sch.T01 = vb:text { text = "Clr Scheme  'Main Groups'" }
  sch.T02 = vb:text { text = "Clr Scheme  'Groups'" }
  sch.T03 = vb:text { text = "Clr Scheme  'SubGroups'" }
  sch.T04 = vb:text { text = "Clr Scheme  'Octaves'" }
  sch.T05 = vb:text { text = "Clr Scheme  'Tracks'" }
  
  
  sch.cT01 = vb:text { text = "Cmb Scheme  'Main Groups'" }
  sch.cT02 = vb:text { text = "Cmb Scheme  'Groups'" }
  sch.cT03 = vb:text { text = "Cmb Scheme  'SubGroups'" }
  sch.cT04 = vb:text { text = "Cmb Scheme  'Tracks'" }


-- Individual Color Buttons --------------------
------------------------------------------------
  sch.iA01 = vb:button { active = F , width = 160 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'Main Group' } --Red
  
  sch.iA02 = vb:button { active = F , width =  80 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'Group' }
  sch.iA03 = vb:button { active = F , width =  80 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'Group' }
  
  sch.iA04 = vb:button { active = F , width =  40 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'SubGroup' }
  sch.iA05 = vb:button { active = F , width =  40 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'SubGroup' }
  sch.iA06 = vb:button { active = F , width =  40 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'SubGroup' }
  sch.iA07 = vb:button { active = F , width =  40 , height = 08 , color = { 0xFF,0x00,0x00 } , tooltip = 'SubGroup' }
  
  sch.iA08 = vb:button { active = F , width =  20 , height = 30 , color = { 0xCC,0x00,0x00 } , tooltip = '01 Track' , text = '1' }
  sch.iA09 = vb:button { active = F , width =  20 , height = 30 , color = { 0x60,0x00,0x00 } , tooltip = '02 Track' , text = '2' }
  sch.iA10 = vb:button { active = F , width =  20 , height = 30 , color = { 0xCC,0x00,0x00 } , tooltip = '01 Track' , text = '1' }
  sch.iA11 = vb:button { active = F , width =  20 , height = 30 , color = { 0x60,0x00,0x00 } , tooltip = '02 Track' , text = '2' }
  sch.iA12 = vb:button { active = F , width =  20 , height = 30 , color = { 0xCC,0x00,0x00 } , tooltip = '01 Track' , text = '1' }
  sch.iA13 = vb:button { active = F , width =  20 , height = 30 , color = { 0x60,0x00,0x00 } , tooltip = '02 Track' , text = '2' }
  sch.iA14 = vb:button { active = F , width =  20 , height = 30 , color = { 0xCC,0x00,0x00 } , tooltip = '01 Track' , text = '1' }
  sch.iA15 = vb:button { active = F , width =  20 , height = 30 , color = { 0x60,0x00,0x00 } , tooltip = '02 Track' , text = '2' }
  ---
  sch.iB02 = vb:button { active = F , width =  80 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'Group' } --Green
  sch.iB03 = vb:button { active = F , width =  80 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'Group' }
  
  sch.iB04 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'SubGroup' }
  sch.iB05 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'SubGroup' }
  sch.iB06 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'SubGroup' }
  sch.iB07 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0xFF,0x2A } , tooltip = 'SubGroup' }
  
  sch.iB08 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x99,0x19 } , tooltip = '01 Track' , text = '1' }
  sch.iB09 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x40,0x19 } , tooltip = '02 Track' , text = '2' }
  sch.iB10 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x99,0x19 } , tooltip = '01 Track' , text = '1' }
  sch.iB11 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x40,0x19 } , tooltip = '02 Track' , text = '2' }
  sch.iB12 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x99,0x19 } , tooltip = '01 Track' , text = '1' }
  sch.iB13 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x40,0x19 } , tooltip = '02 Track' , text = '2' }
  sch.iB14 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x99,0x19 } , tooltip = '01 Track' , text = '1' }
  sch.iB15 = vb:button { active = F , width =  20 , height = 38 , color = { 0x00,0x40,0x19 } , tooltip = '02 Track' , text = '2' }
  ---
  sch.iC04 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0x60,0xFF } , tooltip = 'SubGroup' } --Blue
  sch.iC05 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0x60,0xFF } , tooltip = 'SubGroup' }
  sch.iC06 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0x60,0xFF } , tooltip = 'SubGroup' }
  sch.iC07 = vb:button { active = F , width =  40 , height = 08 , color = { 0x00,0x60,0xFF } , tooltip = 'SubGroup' }
  
  sch.iC08 = vb:button { active = F , width =  20 , height = 46 , color = { 0x00,0x44,0xFF } , tooltip = '01 Track' , text = '1' }
  sch.iC09 = vb:button { active = F , width =  20 , height = 46 , color = { 0x2A,0x3C,0xAA } , tooltip = '02 Track' , text = '2' }
  sch.iC10 = vb:button { active = F , width =  20 , height = 46 , color = { 0x00,0x44,0xFF } , tooltip = '01 Track' , text = '1' }
  sch.iC11 = vb:button { active = F , width =  20 , height = 46 , color = { 0x2A,0x3C,0xAA } , tooltip = '02 Track' , text = '2' }
  sch.iC12 = vb:button { active = F , width =  20 , height = 46 , color = { 0x00,0x44,0xFF } , tooltip = '01 Track' , text = '1' }
  sch.iC13 = vb:button { active = F , width =  20 , height = 46 , color = { 0x2A,0x3C,0xAA } , tooltip = '02 Track' , text = '2' }
  sch.iC14 = vb:button { active = F , width =  20 , height = 46 , color = { 0x00,0x44,0xFF } , tooltip = '01 Track' , text = '1' }
  sch.iC15 = vb:button { active = F , width =  20 , height = 46 , color = { 0x2A,0x3C,0xAA } , tooltip = '02 Track' , text = '2' }
  ---
  sch.iD01 = vb:button { active = F , width =  160 , height = 08 , color = { 0xFF,0x00,0xAA } , tooltip = 'Octaves SGr' } --Pink
  
  sch.iD02 = vb:button { active = F , width =  61 , height = 46 , color = { 0xE0,0x00,0x90 } , tooltip = '0 Octave' , text = '0' }
  sch.iD03 = vb:button { active = F , width =  11 , height = 46 , color = { 0x5D,0x00,0x27 } , tooltip = '1 Octave' } -- , text = '1' }
  sch.iD04 = vb:button { active = F , width =  11 , height = 46 , color = { 0xE0,0x00,0x90 } , tooltip = '2 Octave' } -- , text = '2' }
  sch.iD05 = vb:button { active = F , width =  11 , height = 46 , color = { 0x5D,0x00,0x27 } , tooltip = '3 Octave' } -- , text = '3' }
  sch.iD06 = vb:button { active = F , width =  11 , height = 46 , color = { 0xE0,0x00,0x90 } , tooltip = '4 Octave' } -- , text = '4' }
  sch.iD07 = vb:button { active = F , width =  11 , height = 46 , color = { 0x5D,0x00,0x27 } , tooltip = '5 Octave' } -- , text = '5' }
  sch.iD08 = vb:button { active = F , width =  11 , height = 46 , color = { 0xE0,0x00,0x90 } , tooltip = '6 Octave' } -- , text = '6' }
  sch.iD09 = vb:button { active = F , width =  11 , height = 46 , color = { 0x5D,0x00,0x27 } , tooltip = '7 Octave' } -- , text = '7' }
  sch.iD10 = vb:button { active = F , width =  11 , height = 46 , color = { 0xE0,0x00,0x90 } , tooltip = '8 Octave' } -- , text = '8' }
  sch.iD11 = vb:button { active = F , width =  11 , height = 46 , color = { 0x5D,0x00,0x27 } , tooltip = '9 Octave' } -- , text = '9' }
  ---                            ***
  sch.iE08 = vb:button { active = F , width =  20 , height = 54 , color = { 0xD1,0xD1,0x00 } , tooltip = '01 Track' , text = '1' } --Yellow
  sch.iE09 = vb:button { active = F , width =  20 , height = 54 , color = { 0x61,0x61,0x00 } , tooltip = '02 Track' , text = '2' }
  sch.iE10 = vb:button { active = F , width =  20 , height = 54 , color = { 0xD1,0xD1,0x00 } , tooltip = '03 Track' , text = '3' }
  sch.iE11 = vb:button { active = F , width =  20 , height = 54 , color = { 0x61,0x61,0x00 } , tooltip = '04 Track' , text = '4' }
  sch.iE12 = vb:button { active = F , width =  20 , height = 54 , color = { 0xD1,0xD1,0x00 } , tooltip = '05 Track' , text = '5' }
  sch.iE13 = vb:button { active = F , width =  20 , height = 54 , color = { 0x61,0x61,0x00 } , tooltip = '06 Track' , text = '6' }
  sch.iE14 = vb:button { active = F , width =  20 , height = 54 , color = { 0xD1,0xD1,0x00 } , tooltip = '07 Track' , text = '7' }
  sch.iE15 = vb:button { active = F , width =  20 , height = 54 , color = { 0x61,0x61,0x00 } , tooltip = '08 Track' , text = '8' }


  -- Combined Colors Buttons ---------------------
  ------------------------------------------------
  sch.cA01 = vb:button { active = F , width = 160 , height = 08 , color = Blue_zero ,      tooltip = 'Main Group' } --
  
  sch.cA02 = vb:button { active = F , width =  80 , height = 08 , color = Red_zero ,       tooltip = 'Group' }
  sch.cA03 = vb:button { active = F , width =  80 , height = 08 , color = Yellow_zero ,    tooltip = 'Group' }
  
  sch.cA04 = vb:button { active = F , width =  40 , height = 08 , color = Green_zero ,     tooltip = 'SubGroup' }
  sch.cA05 = vb:button { active = F , width =  40 , height = 08 , color = Sky_Blue_zero ,  tooltip = 'SubGroup' }
  sch.cA06 = vb:button { active = F , width =  40 , height = 08 , color = Pale_Pink_zero , tooltip = 'SubGroup' }
  sch.cA07 = vb:button { active = F , width =  40 , height = 08 , color = Orange_zero ,    tooltip = 'SubGroup' }
  
  sch.cA08 = vb:button { active = F , width =  20 , height = 20 , color = Green_one ,      tooltip = '01 Track' , text = '1' }
  sch.cA09 = vb:button { active = F , width =  20 , height = 20 , color = Green_two ,      tooltip = '02 Track' , text = '2' }
  sch.cA10 = vb:button { active = F , width =  20 , height = 20 , color = Sky_Blue_one ,   tooltip = '01 Track' , text = '1' }
  sch.cA11 = vb:button { active = F , width =  20 , height = 20 , color = Sky_Blue_two ,   tooltip = '02 Track' , text = '2' }
  sch.cA12 = vb:button { active = F , width =  20 , height = 20 , color = Pale_Pink_one ,  tooltip = '01 Track' , text = '1' }
  sch.cA13 = vb:button { active = F , width =  20 , height = 20 , color = Pale_Pink_two ,  tooltip = '02 Track' , text = '2' }
  sch.cA14 = vb:button { active = F , width =  20 , height = 20 , color = Orange_one ,     tooltip = '01 Track' , text = '1' }
  sch.cA15 = vb:button { active = F , width =  20 , height = 20 , color = Orange_two ,     tooltip = '02 Track' , text = '2' }
  ---  
  sch.cB02 = vb:button { active = F , width =  80 , height = 08 , color = Red_zero ,       tooltip = 'Group' } -- 
  sch.cB03 = vb:button { active = F , width =  80 , height = 08 , color = Yellow_zero ,    tooltip = 'Group' }
  
  sch.cB04 = vb:button { active = F , width =  40 , height = 08 , color = Green_zero ,     tooltip = 'SubGroup' }
  sch.cB05 = vb:button { active = F , width =  40 , height = 08 , color = Blue_zero ,      tooltip = 'SubGroup' }
  sch.cB06 = vb:button { active = F , width =  40 , height = 08 , color = Gray_zero ,      tooltip = 'SubGroup' }
  sch.cB07 = vb:button { active = F , width =  40 , height = 08 , color = Sky_Blue_zero ,  tooltip = 'SubGroup' }
  
  sch.cB08 = vb:button { active = F , width =  20 , height = 28 , color = Green_one ,      tooltip = '01 Track' , text = '1' }
  sch.cB09 = vb:button { active = F , width =  20 , height = 28 , color = Green_two ,      tooltip = '02 Track' , text = '2' }
  sch.cB10 = vb:button { active = F , width =  20 , height = 28 , color = Blue_one ,       tooltip = '01 Track' , text = '1' }
  sch.cB11 = vb:button { active = F , width =  20 , height = 28 , color = Blue_two ,       tooltip = '02 Track' , text = '2' }
  sch.cB12 = vb:button { active = F , width =  20 , height = 28 , color = Gray_one ,       tooltip = '01 Track' , text = '1' }
  sch.cB13 = vb:button { active = F , width =  20 , height = 28 , color = Gray_two ,       tooltip = '02 Track' , text = '2' }
  sch.cB14 = vb:button { active = F , width =  20 , height = 28 , color = Sky_Blue_one ,   tooltip = '01 Track' , text = '1' }
  sch.cB15 = vb:button { active = F , width =  20 , height = 28 , color = Sky_Blue_two ,   tooltip = '02 Track' , text = '2' }
  ---
  sch.cC04 = vb:button { active = F , width =  40 , height = 08 , color = Red_zero ,       tooltip = 'SubGroup' } --
  sch.cC05 = vb:button { active = F , width =  40 , height = 08 , color = Green_zero ,     tooltip = 'SubGroup' }
  sch.cC06 = vb:button { active = F , width =  40 , height = 08 , color = Blue_zero ,      tooltip = 'SubGroup' }
  sch.cC07 = vb:button { active = F , width =  40 , height = 08 , color = Yellow_zero ,    tooltip = 'SubGroup' }
  
  sch.cC08 = vb:button { active = F , width =  20 , height = 36 , color = Red_one ,        tooltip = '01 Track' , text = '1' }
  sch.cC09 = vb:button { active = F , width =  20 , height = 36 , color = Red_two ,        tooltip = '02 Track' , text = '2' }
  sch.cC10 = vb:button { active = F , width =  20 , height = 36 , color = Green_one ,      tooltip = '01 Track' , text = '1' }
  sch.cC11 = vb:button { active = F , width =  20 , height = 36 , color = Green_two ,      tooltip = '02 Track' , text = '2' }
  sch.cC12 = vb:button { active = F , width =  20 , height = 36 , color = Blue_one ,       tooltip = '01 Track' , text = '1' }
  sch.cC13 = vb:button { active = F , width =  20 , height = 36 , color = Blue_two ,       tooltip = '02 Track' , text = '2' }
  sch.cC14 = vb:button { active = F , width =  20 , height = 36 , color = Yellow_one ,     tooltip = '01 Track' , text = '1' }
  sch.cC15 = vb:button { active = F , width =  20 , height = 36 , color = Yellow_two ,     tooltip = '02 Track' , text = '2' }
  ---  
  sch.cD08 = vb:button { active = F , width =  20 , height = 44 , color = Yellow_one ,     tooltip = '01 Track' , text = '1' } --
  sch.cD09 = vb:button { active = F , width =  20 , height = 44 , color = Yellow_two ,     tooltip = '02 Track' , text = '2' }
  sch.cD10 = vb:button { active = F , width =  20 , height = 44 , color = White_one ,      tooltip = '03 Track' , text = '3' }
  sch.cD11 = vb:button { active = F , width =  20 , height = 44 , color = White_two ,      tooltip = '04 Track' , text = '4' }
  sch.cD12 = vb:button { active = F , width =  20 , height = 44 , color = Violet_one ,     tooltip = '05 Track' , text = '5' }
  sch.cD13 = vb:button { active = F , width =  20 , height = 44 , color = Violet_two ,     tooltip = '06 Track' , text = '6' }
  sch.cD14 = vb:button { active = F , width =  20 , height = 44 , color = Sky_Blue_one ,   tooltip = '07 Track' , text = '7' }
  sch.cD15 = vb:button { active = F , width =  20 , height = 44 , color = Sky_Blue_two ,   tooltip = '08 Track' , text = '8' }

  
-- Text (Key Commands & About) -----------------
------------------------------------------------

txt_K00 = vb:text {
text =
"* ALT+CTRL + G = Invoke GT16-Colors. Assign manually this Key Command in 'Preferences/Keys... Global/Tools/GT16-Colors'"
}

txt_K01 = vb:text {
text =
"F1 = 'Main Groups' Switch\n"..
"F2 = 'Groups' Switch\n"..
"F3 = 'SubGroups' Switch\n"..
"F4 = 'Tracks' Switch\n"..
"SHIFT + F3 = 'Octaves' Switch\n"..
"\n"..
"← → = Left / Right Select Color\n"..
"↑ ↓ = Up / Down Select Distribution\n"..
"\n"..
"CTRL + PRIOR =  ☲K  Keys info\n"..
"CTRL + NEXT =  ?  About GT16-Colors\n"..
"\n"..
"CTRL + INS =  ⚒  Advanced Tools\n"..
"CTRL + 1,2...9,0 =  Tools Switch\n"..
"CTRL+SHIFT + 2 = SPNO Expand"
}

txt_K02 = vb:text {
text =
"F5 = 'Cmb ...Main Groups' Switch\n"..
"F6 = 'Cmb ...Groups' Switch\n"..
"F7 = 'Cmb ...SubGroups' Switch\n"..
"F8 = 'Cmb ...Tracks' Switch\n"..
"\n"..
"CTRL + Z =  ↩  Undo\n"..
"CTRL + Y =  ↪  Redo\n"..
"\n"..
"CTRL+SHIFT + K =  |≡◄  Coll./Exp. Tr/Gr\n"..
"CTRL+SHIFT + J =  |≡◄  Coll./Exp. Tr in Gr\n"..
"Ç =  ☊  Mute/Unmute Selected Tr/Gr\n"..
"\n"..
"CTRL + HOME =  ⇱  Compact Mode\n"..
"CTRL + END =  ⇱  ... ☲K  ?  ⚒  Closed\n"..
"ESC =  ✖  Exit Window"
}

txt_K03 = vb:text {
text =
"F9   =  |◄  First Tr/Gr Switch\n"..
"F10 =  ◄  Previous Tr/Gr Switch\n"..
"F11 =  ►  Next Tr/Gr Switch\n"..
"F12 =  ►|  Last Tr/Gr Switch\n"..
"\n"..
"CTRL + F9   =  ↶|  Swap Selected Tr to Left\n"..
"CTRL + F10 =  ◄◄  Previous Tr/Gr x2 Switch\n"..
"CTRL + F11 =  ►►  Next Tr/Gr x2 Switch\n"..
"CTRL + F12 =  |↷  Swap Selected Tr/Gr to Right\n"..
"\n"..
"CTRL+SHIFT + DEL = Remove all Tr/Gr\n"..
"CTRL + DEL = Delete Tr/Gr\n"..
"\n"..
"ALT + SPACE = Insert Selection\n"..
"ALT + RETURN = Process SPNO"
}


txt_A01 = vb:multiline_text {
width = 684, height = 130, text = 
"'GT16-Colors' is a free MultiTool created by ulneiz for Renoise, to build & customice various distributions/combinations of 'Groups & Tracks per Colors' for Pattern Editor & Mixer.\n"..
"There are '16 Colors' with until 1200 Options to choose and multiple Tool Modules for control. Select a 'Color', select a 'Distribution' or 'Combination' and build according your needs. With GT16-Colors, the groups are the protagonists!\n"..
"\n"..
"Use only a floating window to control your building. Use the tabs to enlarge or reduce the window. Use the integrated key commands, your mouse or both for maximum control. Use the aditional controls below of each Advanced Tool to discover a new ocean... \n"..
"\n"..
"⚠ Some 'Combined Options' includes many Groups & Tracks (>100), to insert only with a click of mouse or key command.\n"..
"Please, use with moderation!!! Think before using...\n"..
"\n"..
"⚒ Moreover, GT16-Colors include until ten bottom slots to control & edit (Advanced Tools section). This version 1.1 include two powerful tools, 'GTC' (magnificent for control) & 'SPNO' (effective for sort pitches of notes per octaves) integrated in the slots one & two. Apart, if you know the LUA code language, you can add your personal tools here (eight free slots).\n"..
"\n"..
"This version 1.1 of GT16-Colors is tested with Renoise 3.1.0 and work fine.\n"..
"\n"..
"Enjoy your Renoise!   Enjoy your GT16-Colors!\n"..
"\n"..
"                     ✉ To contact ulneiz: visit the Renoise Forums, www.renoise.com"
}

txt_A02 = vb:text { text = "℗ 2016. ulneiz  (Spain)" }

--------------------------------------------------------------------------------
-- MAIN GUI (CONTENT)
--------------------------------------------------------------------------------
content =
vb:column {
  width = 660,    
  margin = 4,
--menu-------------------------------------
  vb:column {
    style = 'group',  --body
    margin = 4,
    vb:horizontal_aligner {
      mode = 'right',
      vb:column {
        vb:horizontal_aligner {
          margin = 2,
          vb:text {
            font = 'bold', --> normal, big, bold, italic, mono
            text = '1.- Select a Principal Option :'
          }   
        }
      },
      vb:column {
        vb:horizontal_aligner{
          vb:column {
            width = 465,
            vb:horizontal_aligner {
            --width = 700,
            swi_cl_menu, --menu
            },
          },
          vb:column {
            vb:horizontal_aligner {          
              vb:text { text = 'Bars ' },
              checkbox_bars --bars
            }
          }
        }
      }
    },    
  --tabs-----------------
    vb:column {
      visible = false,
      id = 'tab_com',
      height = 4
    },
  -----------------------
    vb:column {
      visible = false,
      id = 'tab_mgr',
      style = 'panel',
      width = 695,
      vb:horizontal_aligner {
        mode = 'justify',
      margin = 10,
        vb:column { --01
          vb:text {
            font = 'bold',
            text = '2.- Select a Main Color & a Main Group distribution :'
          },
          vb:horizontal_aligner { height = 5 },
          swi_cl_mgr,
          vb:horizontal_aligner {
            but_mgr.aq, but_mgr.bk, but_mgr.bl, but_mgr.br, but_mgr.gl, but_mgr.gy, but_mgr.gr, but_mgr.og, but_mgr.pl, but_mgr.pn, but_mgr.ps, but_mgr.rd, but_mgr.sk, but_mgr.vl, but_mgr.wh, but_mgr.yl
          },
          vb:horizontal_aligner { height = 10 },
          vb:column {
            width = 484,
            mgroup,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert MGr',
                id = 'bt_insert_mgr',
                tooltip = 'Insert Main Groups with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_01() end
              }
            }
          }
        },
        vb:column { --02
        vb:horizontal_aligner { height = 24 },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.T01 },
            vb:horizontal_aligner { sch.iA01 },
            vb:horizontal_aligner { sch.iA02 , sch.iA03 },
            vb:horizontal_aligner { sch.iA04 , sch.iA05 , sch.iA06 , sch.iA07 },
            vb:horizontal_aligner { sch.iA08 , sch.iA09 , sch.iA10 , sch.iA11 , sch.iA12 , sch.iA13 , sch.iA14 , sch.iA15 }
          }
        }
      }
    },
  -----------------------
    vb:column {
      visible = false,
      id = 'tab_grp',
      style = 'panel',
      width = 695,
      vb:horizontal_aligner {
        mode = 'justify',
        margin = 10,
        vb:column { --01
          vb:text {
            font = 'bold',
            text = '2.- Select a Main Color & a Group distribution :'
          },
          vb:horizontal_aligner { height = 5 },
          swi_cl_gr,
          vb:horizontal_aligner {
            but_gr.aq, but_gr.bk, but_gr.bl, but_gr.br, but_gr.gl, but_gr.gy, but_gr.gr, but_gr.og, but_gr.pl, but_gr.pn, but_gr.ps, but_gr.rd, but_gr.sk, but_gr.vl, but_gr.wh, but_gr.yl
          },
          vb:horizontal_aligner { height = 10 },
          vb:column {
            width = 484,
            group,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Gr',
                id = 'bt_insert_gr',
                tooltip = 'Insert Groups with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_02() end
              }
            }
          }
        },
        vb:column { --02
        vb:horizontal_aligner { height = 24 },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.T02 },
            vb:horizontal_aligner { sch.iB02 , sch.iB03 },
            vb:horizontal_aligner { sch.iB04 , sch.iB05 , sch.iB06 , sch.iB07 },
            vb:horizontal_aligner { sch.iB08 , sch.iB09 , sch.iB10 , sch.iB11 , sch.iB12 , sch.iB13 , sch.iB14 , sch.iB15 }
          }
        }
      }
    },
  -----------------------
    vb:column {
      visible = false,
      id = 'tab_sgr',
      style = 'panel',
      width = 695,
      vb:column {
        margin = 10,
        vb:horizontal_aligner {
          mode = 'justify',
          vb:column {
            vb:text {
              font = 'bold',
              text = '2.- Select a Main Color & a SubGroup or Octaves distribution :'
            }
          },
          vb:column {
            swi_cl_sgrmenu
          }
        },
        vb:horizontal_aligner { height = 5 },
    -----------------------    
        vb:column {
          visible = false,
          id = 'sgrtab_sgr',
          vb:horizontal_aligner {
            mode = 'justify',
            vb:column {
              width = 495,        
              swi_cl_sgr,
              vb:horizontal_aligner {
                but_sgr.aq, but_sgr.bk, but_sgr.bl, but_sgr.br, but_sgr.gl, but_sgr.gy, but_sgr.gr, but_sgr.og, but_sgr.pl, but_sgr.pn, but_sgr.ps, but_sgr.rd, but_sgr.sk, but_sgr.vl, but_sgr.wh, but_sgr.yl
              },
              vb:horizontal_aligner { height = 10 },
              vb:column {
                width = 484,
                sgroup,
                vb:horizontal_aligner { height = 10 },
              --button-------------------------------------
                vb:horizontal_aligner {
                  mode = 'center',
                  vb:button {
                    color = { 0x00,0x60,0x00 },
                    text = 'Insert SGr',
                    id = 'bt_insert_sgr',
                    tooltip = 'Insert SubGroups with selected Color\n[ALT + SPACE]',
                    height = 26,
                    width = '65%',
                    notifier = function()insert_03() end
                  }
                }
              }
            },
            vb:column { --02
            vb:horizontal_aligner { height = 1 },
              vb:column {
                style = 'group',
                margin = 10,
                vb:horizontal_aligner { mode = 'center', sch.T03 },
                vb:horizontal_aligner { sch.iC04 , sch.iC05 , sch.iC06 , sch.iC07 },
                vb:horizontal_aligner { sch.iC08 , sch.iC09 , sch.iC10 , sch.iC11 , sch.iC12 , sch.iC13 , sch.iC14 , sch.iC15 }
              }
            }
          }
        },
        --- ---
        vb:column {
          visible = false,
          id = 'sgrtab_oct',
          vb:horizontal_aligner {
            mode = 'justify',
            vb:column {      
            width = 495,
              swi_cl_oct,
              vb:horizontal_aligner {
                but_oct.aq, but_oct.bk, but_oct.bl, but_oct.br, but_oct.gl, but_oct.gy, but_oct.gr, but_oct.og, but_oct.pl, but_oct.pn, but_oct.ps, but_oct.rd, but_oct.sk, but_oct.vl, but_oct.wh, but_oct.yl
              },
              vb:horizontal_aligner { height = 10 },
              vb:column {
                width = 484,
                octave,
                vb:horizontal_aligner { height = 10 },
              --button-------------------------------------
                vb:horizontal_aligner {
                  mode = 'center',
                  vb:button {
                    color = { 0x00,0x60,0x00 },
                    text = 'Insert Oct',
                    id = 'bt_insert_oct',
                    tooltip = 'Insert Octaves with selected Color\n[ALT + SPACE]',
                    height = 26,
                    width = '65%',
                    notifier = function()insert_oct() end
                  }
                }
              }
            },
            vb:column { --02
            vb:horizontal_aligner { height = 1 },        
              vb:column {
                style = 'group',
                margin = 10,
                vb:horizontal_aligner { mode = 'center', sch.T04 },
                vb:horizontal_aligner { sch.iD01 },
                vb:horizontal_aligner { sch.iD02 , sch.iD03 , sch.iD04 , sch.iD05 , sch.iD06 , sch.iD07 , sch.iD08 , sch.iD09 , sch.iD10 , sch.iD11 }
              }
            }
          }
        }
        --- ---
      }
    },  
  -----------------------
    vb:column {
      visible = false,
      id = 'tab_trk',
      style = 'panel',
      width = 695,
      vb:horizontal_aligner {
        mode = 'justify',
        margin = 10,
        vb:column { --01
          vb:text {
            font = 'bold',
            text = '2.- Select a Main Color & a Track distribution :'
          },
          vb:horizontal_aligner { height = 5 },
          swi_cl_tr,
          vb:horizontal_aligner {
            but_tr.aq, but_tr.bk, but_tr.bl, but_tr.br, but_tr.gl, but_tr.gy, but_tr.gr, but_tr.og, but_tr.pl, but_tr.pn, but_tr.ps, but_tr.rd, but_tr.sk, but_tr.vl, but_tr.wh, but_tr.yl
          },
          vb:horizontal_aligner { height = 10 },
          vb:column {
            width = 484,
            track,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Tr',
                id = 'bt_insert_tr',
                tooltip = 'Insert Tracks with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_04() end
              }
            }
          }
        },
      vb:column { --02
        vb:horizontal_aligner { height = 24 },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.T05 },
            vb:horizontal_aligner { sch.iE08 , sch.iE09 , sch.iE10 , sch.iE11 , sch.iE12 , sch.iE13 , sch.iE14 , sch.iE15 }
          }
        }
      }
    },
  --submenu----------------------
    vb:column {
      visible = false,
      id = 'tab_cmb',
      style = 'panel',
      margin = 10,
      vb:horizontal_aligner { 
        spacing = 10,
        mode = 'left',
        swi_cl_smenu --submenu
      },
    --subtabs-----------------------
      vb:column {
        visible = false,
        id = 'subtab_mgr',
        style = 'panel',
        width = 682,
        margin = 7,
        vb:horizontal_aligner {
          mode = "justify",
          vb:column {
          width = 470,
            vb:text {
              font = 'bold',
              text = '2.- Select a Combined Main Groups distribution :'
            },
            vb:horizontal_aligner { height = 5 },
            mgrcom,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Cmb MGr',
                id = 'bt_insert_cmgr',
                tooltip = 'Insert Combined Main Groups with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_05() end
              }
            }
          },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.cT01 },
            vb:horizontal_aligner { sch.cA01 },
            vb:horizontal_aligner { sch.cA02 , sch.cA03 },
            vb:horizontal_aligner { sch.cA04 , sch.cA05 , sch.cA06 , sch.cA07 },
            vb:horizontal_aligner { sch.cA08 , sch.cA09 , sch.cA10 , sch.cA11 , sch.cA12 , sch.cA13 , sch.cA14 , sch.cA15 }
          }
        }
      },
    --------------------------------------
      vb:column {
        visible = false,
        id = 'subtab_grp',
        style = 'panel',
        width = 682,
        margin = 7,
        vb:horizontal_aligner {
          mode = "justify",
          vb:column {
            width = 470,
            vb:text {
              font = 'bold',
              text = '2.- Select a Combined Groups distribution :'
            },
            vb:horizontal_aligner { height = 5 },
            grcom,
            vb:horizontal_aligner { height = 10 },
          --button--------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Cmb Gr',
                id = 'bt_insert_cgr',
                tooltip = 'Insert Combined Groups with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_06() end
              }
            }
          },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.cT02 },
            vb:horizontal_aligner { sch.cB02 , sch.cB03 },
            vb:horizontal_aligner { sch.cB04 , sch.cB05 , sch.cB06 , sch.cB07 },
            vb:horizontal_aligner { sch.cB08 , sch.cB09 , sch.cB10 , sch.cB11 , sch.cB12 , sch.cB13 , sch.cB14 , sch.cB15 }
          }
        }
      },
    -----------------------------
      vb:column {
        visible = false,
        id = 'subtab_sgr',
        style = 'panel',
        width = 682,
        margin = 7,
        vb:horizontal_aligner {
          mode = "justify",
          vb:column {
            width = 470,
            vb:text {
              font = 'bold',
              text = '2.- Select a Combined SubGroups distribution :'
            },
            vb:horizontal_aligner { height = 5 },
            sgrcom,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Cmb SGr',
                id = 'bt_insert_csgr',
                tooltip = 'Insert Combined SubGroups with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_07() end
              }
            }
          },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.cT03 },
            vb:horizontal_aligner { sch.cC04 , sch.cC05 , sch.cC06 , sch.cC07 },
            vb:horizontal_aligner { sch.cC08 , sch.cC09 , sch.cC10 , sch.cC11 , sch.cC12 , sch.cC13 , sch.cC14 , sch.cC15 }
          }
        }
      },
    -------------------------------
      vb:column {
        visible = false,
        id = 'subtab_trk',
        style = 'panel',
        width = 682,
        margin = 7,
        vb:horizontal_aligner {
          mode = "justify",
          vb:column {
            width = 470,
            vb:text {
              font = 'bold',
              text = '2.- Select a Combined Tracks distribution :'
            },
            vb:horizontal_aligner { height = 5 },
            trcom,
            vb:horizontal_aligner { height = 10 },
          --button-------------------------------------
            vb:horizontal_aligner {
              mode = 'center',
              vb:button {
                color = { 0x00,0x60,0x00 },
                text = 'Insert Cmb Tr',
                id = 'bt_insert_ctr',
                tooltip = 'Insert Combined Tracks with selected Color\n[ALT + SPACE]',
                height = 26,
                width = '65%',
                notifier = function()insert_08() end
              }
            }
          },
          vb:column {
            style = 'group',
            margin = 10,
            vb:horizontal_aligner { mode = 'center', sch.cT04 },
            vb:horizontal_aligner { sch.cD08 , sch.cD09 , sch.cD10 , sch.cD11 , sch.cD12 , sch.cD13 , sch.cD14 , sch.cD15 }
          }
        }
      }
    },
  --NavTracks-------------------------------
    vb:horizontal_aligner {
      swi_cl_hmenu, --hmenu
      vb:horizontal_aligner { width = 3 },
      --- --- --- ---
      vb:horizontal_aligner {
        width = 41,
        margin = 2,
        vb:column {
          tooltip = 'Number of Index Group/Track Selected.\nSelect any Track to reactivate!',
          width = 41,
          style = 'body',
          vb:horizontal_aligner {
            height = 21,
            mode = 'center',
            vb: text {
              font = 'bold',
              align = 'center',
              id = 'tr_index',  -- ID
              text = '---'
            }
          }
        }
      },
      vb:horizontal_aligner {
        width = 41,
        margin = 2,
        vb:column {
          tooltip = 'Total Count of Groups & Tracks.\nSelect any Track to reactivate!',
          width = 41,
          style = 'body',
          vb:horizontal_aligner {
            height = 21,
            mode = 'center',
            vb: text {
              font = 'bold',
              align = 'center',
              id = 'tr_count',  -- ID
              text = '---'
            }
          }
        }
      },
      vb:button {
        active = F,
        id = 'bar_count',  -- ID
        color = { 0x00,0x00,0x00 }, -- black 
        tooltip = 'Green: Low Level of Members (until 48).\nOrange: Middle Level of Members (49 until 96).\nRed: High Level of Members (more of 96).',
        height = 24,
        width = 7
      },
      vb:horizontal_aligner {
        tooltip = 'Total Number of Send Tracks.\nSelect any Track to reactivate!',
        width = 41,
        margin = 2,
        vb:column {
          width = 41,
          style = 'body',
          vb:horizontal_aligner {
            height = 21,
            mode = 'center',
            vb: text {
              font = 'bold',
              align = 'center',
              id = 'tr_send',  -- ID
              text = '---'
            }
          }
        }
      },
      -- vb:valuebox {
        -- id = "tr_index", -- Added so that you can identify which GUI control to update
        -- tooltip = 'Track Index',
        -- width = 60,
        -- height = 24,
        -- min = 1,
        -- notifier = function(value) renoise.song().selected_track_index = value end
      -- },
    --- --- --- ---
      vb:horizontal_aligner { width = 5 },
      vb:button {
        color = { 0xAA,0x6A,0x00 },
        text = '↩',
        id = 'navt_undo',
        tooltip = 'Undo  \n[CTRL + Z]',
        height = 24,
        width = 40,
        notifier = function()navt_undo() end
      },
      vb:button {
        color = { 0xAA,0x6A,0x00 },
        text = '↪',
        id = 'navt_redo',
        tooltip = 'Redo  \n[CTRL + Y]',
        height = 24,
        width = 40,
        notifier = function()navt_redo() end
      },
      vb:horizontal_aligner { width = 4 },
      vb:button {
        color = { 0x66,0x00,0x00 },
        text = 'REM',
        id = 'navt_cln',
        tooltip = 'Remove all Tracks/Groups inside Pattern Editor (least the first) & Start Again!\n[CTRL+SHIFT + DEL]\n⚠ Limited until 99 members. All expanded!',
        height = 24,
        width = 40,
        notifier = function()navt_rem() end
      },
      vb:button {
        color = { 0x66,0x00,0x00 },
        text = 'DEL',
        id = 'navt_del',
        tooltip = 'Delete Selected Track/Group/Send\n[CTRL + DEL]',
        height = 24,
        width = 40,
        notifier = function()navt_del() end
      },
      vb:horizontal_aligner { width = 4 },
      vb:button {
        color = { 0x06,0x3B,0x70 },
        text = '☊',
        id = 'note_on_off',
        tooltip = "'Play/Off' Selected Track/Group/Send  (Master not included)\n[Ç]",
        height = 24,
        width = 30,
        notifier = function() navt_on_off() end
      },
      vb:button {
        color = { 0x7F,0x05,0x54 },
        text = '|≡◄ ',
        id = 'collapse_expand_gr',
        tooltip = "'Collapse/Expand' all Tracks inside the Group Parent\n[CTRL+SHIFT + J]\nor\n'Collapse/Expand' Selected Track/Master/Send\n[CTRL+SHIFT + K]",
        height = 24,
        width = 40,
        notifier = function() navt_coll_gr() end
      },
      vb:horizontal_aligner { width = 4 },
      vb:button {
        color = { 0x4F,0x0C,0x89 },
        text = '|◄',
        id = 'navt_first',
        tooltip = 'First Track/Group \n[F9]',
        height = 24,
        width = 30,
        notifier = function()navt_first() end
      },
      vb:button {
        color = { 0x4F,0x0C,0x89 },
        text = '◄◄  ◄',
        id = 'navt_02',
        tooltip = 'Previous Track/Group\n[F10]\nor\nPrevious Track/Group x2\n[CTRL + F10]',
        height = 24,
        width = 50,
        notifier = function()navt_02() end
      },
      vb:button {
        color = { 0x4F,0x0C,0x89 },
        text = '►  ►►',
        id = 'navt_03',
        tooltip = 'Next Track/Group\n[F11]\nor\nNext Track/Group x2\n[CTRL + F11]',
        height = 24,
        width = 50,
        notifier = function()navt_04() end
      },
      vb:button {
        color = { 0x4F,0x0C,0x89 },
        text = '►|',
        id = 'navt_last',
        tooltip = 'Last Track/Group\n[F12]',
        height = 24,
        width = 30,
        notifier = function()navt_last() end
      },
      vb:horizontal_aligner { width = 4 },
      vb:button {
        color = { 0x40,0x00,0x80 },
        text = '↶|',
        id = 'navt_swap_left',
        tooltip = 'Swap Selected Track to Left\n[CTRL + F9]',
        height = 24,
        width = 30,
        notifier = function()navt_swap_left() end
      },
      vb:button {
        color = { 0x40,0x00,0x80 },
        text = '|↷',
        id = 'navt_swap_right',
        tooltip = 'Swap Selected Track to Right\n[CTRL + F12]',
        height = 24,
        width = 30,
        notifier = function()navt_swap_right() end
      },
    },
  --NavColumns - NavTracks-------------------------------
    vb:column {
      id ='cbox_bars_f',
      visible = false,
    },  
    vb:column {
      id = 'cbox_bars_t',
      visible = false,
      vb:horizontal_aligner { height = 5 },
      vb:horizontal_aligner {
        mode = 'justify',
        vb:horizontal_aligner {
          width = 120,
          vb:slider {
            id = 'nav_col',
            min = 0, --1,
            max = 1, --12, --renoise.song().tracks[ renoise.song().selected_track_index ].visible_note_columns
            value = 0, --1,
            width = 120,
            -- notifier = function(value) renoise.song().selected_note_column_index = value end,
            notifier = function(val)
		      if ( renoise.song().selected_track.type == renoise.Track.TRACK_TYPE_SEQUENCER ) then
                local num_column =  renoise.song().tracks[ renoise.song().selected_track_index ].visible_note_columns - 1
                local col_idx = math.floor( val * num_column ) + 1
                renoise.song().selected_note_column_index = col_idx
                print( 'col_idx: ' ..col_idx )
              end
			end
          }
        },
        ---
      vb:horizontal_aligner {
        width = 570,
        vb:slider {
          id = 'nav_track',
          min = 0, --1,
          max = 1, --2, --renoise.song().sequencer_track_count + 1 + renoise.song().send_track_count,
          value = 0, --1,
          width = 530,
        --notifier = function(value) renoise.song().selected_track_index = value end,
        notifier = function(val)
            local num_tracks =  renoise.song().sequencer_track_count + renoise.song().send_track_count
            local track_idx = math.floor( val * num_tracks ) + 1
            renoise.song().selected_track_index = track_idx
        print( 'track_idx: ' ..track_idx )
          end
        },
      vb:text {
          id = 'index_value',
        text = '---'
      },
    vb:text {
          id = 'col_value',
        text = '---'
      }
      }
    }
    }
    ---
  },  
  --hlpmenu----------------------------------
  vb:column {
    visible = false,
    id = 'hlptab_cls'
  },
  ----------------------------- Keys
  vb:column {
    vb:horizontal_aligner { height = 5 },
    visible = false,
    id = 'hlptab_hlp',
    vb:column {
      style = 'group',
      margin = 5,
      vb:horizontal_aligner { 
        vb:text {
          font = 'bold',
          text = '☲K  Key Commands'
        }  
      },
      vb:horizontal_aligner { height = 5 },
      vb:column {
        style = 'body',
        width = 694,
        height = 24,
        margin = 8,
        txt_K00
      },
      vb:horizontal_aligner { height = 5 },    
      vb:horizontal_aligner {
        mode = "justify",
      vb:column {
          style = 'body',
          width = 206,
          height = '100%',
          margin = 8,
          txt_K01
        },
        vb:column {
          style = 'body',
          width = 226,
          height = '100%',
          margin = 8,
          txt_K02
        },
        vb:column {
          style = 'body',
          width = 252,
          height = '100%',
          margin = 8,
          txt_K03
        }
      }
    }
  },
  ------------------------------- About
  vb:column {
    vb:horizontal_aligner { height = 5 },
    visible = false,
    id = 'hlptab_abo',
    vb:column {
      style = 'group',
      margin = 5,
      vb:horizontal_aligner {
        mode = 'justify',
        vb:column {
          vb:text {
            font = 'bold',
            text = '? About GT16-Colors   v1.1'
          }   
        },
        vb:column {
          vb:horizontal_aligner {
            but_cm.aq, but_cm.bk, but_cm.bl, but_cm.br, but_cm.gl, but_cm.gy, but_cm.gr, but_cm.og, but_cm.pl, but_cm.pn, but_cm.ps, but_cm.rd, but_cm.sk, but_cm.vl, but_cm.wh, but_cm.yl
          }
        }
      },
      vb:horizontal_aligner { height = 5 },
      vb:column {
        style = 'body',
        height = '100%',
        margin = 5,
        txt_A01,
        vb:horizontal_aligner {
          mode = 'right',
          txt_A02
        }
      }
    }
  },
  ------------------------------------- Advanced Tools (Pattern Editor)
  vb:column {
    vb:horizontal_aligner { height = 5 },
    visible = false,
    id = 'hlptab_tls',
    vb:column {	
      style = 'group',
      --width = 668,
      margin = 5,
      vb:horizontal_aligner {
        mode = 'justify',
        vb:column {
          vb:horizontal_aligner {
            vb:text {
              font = 'big',
              text = '⚒'
            },
            vb:text {
              font = 'bold',
              text = 'Advanced Tools'
            },
            vb:text {
              font = 'italic',
              text = ' ( for Pattern Editor, Mixer & more... )'
            }
          }
        },
        vb:column {
          swi_cl_tmenu
        }
      },
      -------------------------------Tool 01
      vb:column {
        visible = false,
        id = 'tlstab_01',
        style = 'body',
        width = 694,
        margin = 08,
        --- ---
        GTC, --Added Tool 01
        --- ---
      },
      -------------------------------Tool 02
      vb:column {
        visible = false,
        id = 'tlstab_02',
        style = 'body',
        width = 694,
        margin = 08,
        --- ---
        SPNO, --Added Tool 02
        --- ---
      },
      -------------------------------Tool 03
      vb:column {
        visible = false,
        id = 'tlstab_03',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 03' },
        },
        --Add Tool 03
      },
      -------------------------------Tool 04
      vb:column {
        visible = false,
        id = 'tlstab_04',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 04' },
        },
        --Add Tool 04
      },
      -------------------------------Tool 05
      vb:column {
        visible = false,
        id = 'tlstab_05',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 05' },
        },
        --Add Tool 05
      },
      -------------------------------Tool 06
      vb:column {
        visible = false,
        id = 'tlstab_06',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 06' },
        },
        --Add Tool 06
      },
      -------------------------------Tool 07
      vb:column {
        visible = false,
        id = 'tlstab_07',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 07' },
        },
        --Add Tool 07
      },
      -------------------------------Tool 08
      vb:column {
        visible = false,
        id = 'tlstab_08',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 08' },
        },
        --Add Tool 08
      },
      -------------------------------Tool 09
      vb:column {
        visible = false,
        id = 'tlstab_09',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 09' },
        },
        --Add Tool 09
      },
      -------------------------------Tool 10
      vb:column {
        visible = false,
        id = 'tlstab_10',
        style = 'body',
        width = 702,
        margin = 08,
        vb:horizontal_aligner {
          vb:text { text = 'Tool 10' }
        },
        --Add Tool 10
      }
    }
  }
}
------------------------------------------------------------
  show_tab(2)    -- 2  1 -- start the things
  show_sgrtab(1) -- 1  1 
  show_subtab(1) -- 1  1
  show_hlptab(1) -- 1  4
  show_tlstab(1) -- 1  3 


--------------------------------------------------------------------------------
-- SHOW_DIALOG ( KEYHANDLER )
--------------------------------------------------------------------------------
function show_dialog(add_notifier)
  -- Prevents duplicate of the floating window ( when reaching this, the dialog never was created before or was closed )
  if dialog and dialog.visible then dialog:show() return end  
  
  
  -- keyhandler ----------------------------------
  ------------------------------------------------
  local function keyhandler( dialog, key )
    rprint(key)   -- print the value of key to the console
    -- return key -- uncomment to pass key on to Renoise
    local choice_via_shortcut = nil
    -- Insert, Process --------------------------------------------------------------------------------
        if ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_menu.value ==  2 ) then choice_via_shortcut = 'Insert MGr' insert_01()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_menu.value ==  3 ) then choice_via_shortcut = 'Insert Gr'  insert_02()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_menu.value ==  4 and swi_cl_sgrmenu.value == 1) then choice_via_shortcut = 'Insert SGr' insert_03()
  elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_menu.value ==  4 and swi_cl_sgrmenu.value == 2) then choice_via_shortcut = 'Insert Oct' insert_oct()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_menu.value ==  5 ) then choice_via_shortcut = 'Insert Tr'  insert_04()
  ---
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_smenu.value == 1 ) then choice_via_shortcut = 'Insert Comb. MGr' insert_05()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_smenu.value == 2 ) then choice_via_shortcut = 'Insert Comb. Gr'  insert_06()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_smenu.value == 3 ) then choice_via_shortcut = 'Insert Comb. SGr' insert_07()
    elseif ( key.modifiers == 'alt' and key.name == 'space'  and swi_cl_smenu.value == 4 ) then choice_via_shortcut = 'Insert Comb. Tr'  insert_08()
  ---
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 1 ) then choice_via_shortcut = 'Process Tool 01'  process_01()
  elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 2 ) then choice_via_shortcut = 'Process Tool 02'  process_02()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 3 ) then choice_via_shortcut = 'Process Tool 03'  process_03()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 4 ) then choice_via_shortcut = 'Process Tool 04'  process_04()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 5 ) then choice_via_shortcut = 'Process Tool 05'  process_05()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 6 ) then choice_via_shortcut = 'Process Tool 06'  process_06()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 7 ) then choice_via_shortcut = 'Process Tool 07'  process_07()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 8 ) then choice_via_shortcut = 'Process Tool 08'  process_08()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 9 ) then choice_via_shortcut = 'Process Tool 09'  process_09()
  --elseif ( key.modifiers == 'alt' and key.name == 'return' and swi_cl_tmenu.value == 10) then choice_via_shortcut = 'Process Tool 10'  process_10()
    -- Switches ------------------------------------------------------------------------------
    elseif ( key.name == 'f1' ) then choice_via_shortcut = 'MGr'  vb.views[ 'main_switch' ].value = 2 
    elseif ( key.name == 'f2' ) then choice_via_shortcut = 'Gr'   vb.views[ 'main_switch' ].value = 3
  elseif ( key.modifiers == 'shift' and key.name == 'f3' ) then choice_via_shortcut = 'Oct' vb.views[ 'main_switch' ].value = 4 vb.views[ 'subgroup_switch' ].value = 2
  elseif ( key.name == 'f3' ) then choice_via_shortcut = 'SGr'  vb.views[ 'main_switch' ].value = 4 vb.views[ 'subgroup_switch' ].value = 1
  elseif ( key.name == 'f4' ) then choice_via_shortcut = 'Tr'   vb.views[ 'main_switch' ].value = 5
    elseif ( key.name == 'f5' ) then choice_via_shortcut = 'CMGr' vb.views[ 'main_switch' ].value = 6  vb.views[ 'submain_switch' ].value = 1
    elseif ( key.name == 'f6' ) then choice_via_shortcut = 'CGr'  vb.views[ 'main_switch' ].value = 6  vb.views[ 'submain_switch' ].value = 2
    elseif ( key.name == 'f7' ) then choice_via_shortcut = 'CSGr' vb.views[ 'main_switch' ].value = 6  vb.views[ 'submain_switch' ].value = 3
    elseif ( key.name == 'f8' ) then choice_via_shortcut = 'CTr'  vb.views[ 'main_switch' ].value = 6  vb.views[ 'submain_switch' ].value = 4
    -- NavTracks, Exit, Wipe & Del -----------------------------------------------------------------
    elseif ( key.modifiers == 'control' and key.name == 'f9' )  then choice_via_shortcut = 'Swap Selected Track to Left' navt_swap_left()
    elseif ( key.name == 'f9'  ) then choice_via_shortcut = 'First Track' navt_first()
    elseif ( key.modifiers == 'control' and key.name == 'f10' )  then choice_via_shortcut = 'Previous Track x 2' navt_01()
    elseif ( key.name == 'f10' ) then choice_via_shortcut = 'Previous Track' navt_02()
    elseif ( key.modifiers == 'control' and key.name == 'f11' )  then choice_via_shortcut = 'Next Track x 2' navt_03()
    elseif ( key.name == 'f11' ) then choice_via_shortcut = 'Next Track' navt_04()
    elseif ( key.modifiers == 'control' and key.name == 'f12' )  then choice_via_shortcut = 'Swap Selected Track/Main Group to Right' navt_swap_right()
    elseif ( key.name == 'f12' ) then choice_via_shortcut = 'Last Track' navt_last()
    elseif ( key.name == 'esc' ) then choice_via_shortcut = 'Exit' dialog:close()  -- (key.name == 'esc' or key.name == 'e') -- ...or 'e'
    elseif ( key.name == 'ç' )   then choice_via_shortcut = 'Active/Off Track/Group' navt_on_off()
  elseif ( key.modifiers == 'shift + control' and key.name == 'k' ) then choice_via_shortcut = 'Collapse/Expand Track/Group' navt_coll()
  elseif ( key.modifiers == 'control' and key.name == 'z' ) then choice_via_shortcut = 'Undo' navt_undo()
    elseif ( key.modifiers == 'control' and key.name == 'y' ) then choice_via_shortcut = 'Undo' navt_redo()
  elseif ( key.modifiers == 'shift + control' and key.name == 'del' ) then choice_via_shortcut = 'Delelte' navt_rem()
    elseif ( key.modifiers == 'control' and key.name == 'del' ) then choice_via_shortcut = 'Delelte' navt_del()
    -- Close below, Keys, & About -----------------------------------------------------------------
    elseif ( key.modifiers == 'control' and key.name == 'ins' ) then choice_via_shortcut = 'Advanced Tools' vb.views[ 'help_switch' ].value = 4 vb.views[ 'main_switch' ].value = 1
    elseif ( key.modifiers == 'control' and key.name == 'home' ) then choice_via_shortcut = 'Compact Window'   vb.views[ 'main_switch' ].value = 1
    elseif ( key.modifiers == 'control' and key.name == 'end' ) then choice_via_shortcut = 'Close Window' vb.views[ 'help_switch' ].value = 1
    elseif ( key.modifiers == 'control' and key.name == 'prior' ) then choice_via_shortcut = 'Key Commands' vb.views[ 'help_switch' ].value = 2
    elseif ( key.modifiers == 'control' and key.name == 'next' ) then choice_via_shortcut = 'About' vb.views[ 'help_switch' ].value = 3
  -- Advanced Tools ------------------------------------------------------------------------
  elseif ( key.modifiers == 'shift + control' and key.name == '2' ) then choice_via_shortcut =
            'Tool 02' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 2 vb.views[ 'main_switch' ].value = 4 vb.views[ 'subgroup_switch' ].value = 2
  elseif ( key.modifiers == 'control' and key.name == '1' ) then choice_via_shortcut = 'Tool 01' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 1
  elseif ( key.modifiers == 'control' and key.name == '2' ) then choice_via_shortcut = 'Tool 02' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 2
  elseif ( key.modifiers == 'control' and key.name == '3' ) then choice_via_shortcut = 'Tool 03' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 3
  elseif ( key.modifiers == 'control' and key.name == '4' ) then choice_via_shortcut = 'Tool 04' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 4
  elseif ( key.modifiers == 'control' and key.name == '5' ) then choice_via_shortcut = 'Tool 05' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 5
  elseif ( key.modifiers == 'control' and key.name == '6' ) then choice_via_shortcut = 'Tool 06' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 6
  elseif ( key.modifiers == 'control' and key.name == '7' ) then choice_via_shortcut = 'Tool 07' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 7
  elseif ( key.modifiers == 'control' and key.name == '8' ) then choice_via_shortcut = 'Tool 08' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 8
  elseif ( key.modifiers == 'control' and key.name == '9' ) then choice_via_shortcut = 'Tool 09' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 9
  elseif ( key.modifiers == 'control' and key.name == '0' ) then choice_via_shortcut = 'Tool 10' vb.views[ 'help_switch' ].value = 4 vb.views[ 'tools_switch' ].value = 10
    end
    ----
    local vb_switch = vb.views[ 'mgr_switch_cl' ]
    if ( key.name == 'right' and swi_cl_menu.value == 2 ) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_menu.value == 2 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1 )
    end
    local vb_popup = vb.views[ 'mgr_popup' ]
    if ( key.name == 'down' and swi_cl_menu.value == 2 ) then
      vb_popup.value = math.min(#vb_popup.items,vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_menu.value == 2 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_switch = vb.views[ 'gr_switch_cl' ]
    if ( key.name == 'right' and swi_cl_menu.value == 3) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_menu.value == 3 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1 )
    end
    local vb_popup = vb.views[ 'gr_popup' ]
    if ( key.name == 'down' and swi_cl_menu.value == 3 ) then
      vb_popup.value = math.min( #vb_popup.items,vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_menu.value == 3 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_switch = vb.views[ 'sgr_switch_cl' ]
    if ( key.name == 'right' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 1 ) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 1 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1 )
    end
    local vb_popup = vb.views[ 'sgr_popup' ]
    if ( key.name == 'down' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 1 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 1 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
  local vb_switch = vb.views[ 'oct_switch_cl' ]
    if ( key.name == 'right' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 2 ) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 2 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1 )
    end
    local vb_popup = vb.views[ 'oct_popup' ]
    if ( key.name == 'down' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 2 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_menu.value == 4 and swi_cl_sgrmenu.value == 2 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_switch = vb.views[ 'tr_switch_cl' ]
    if ( key.name == 'right' and swi_cl_menu.value == 5 ) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_menu.value == 5 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1 )
    end
    local vb_popup = vb.views[ 'tr_popup' ]
    if ( key.name == 'down' and swi_cl_menu.value == 5 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_menu.value == 5 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end

    ----

    local vb_popup = vb.views[ 'cmgr_popup' ]
    if ( key.name == 'down' and swi_cl_smenu.value == 1 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_smenu.value == 1 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_popup = vb.views[ 'cgr_popup' ]
    if ( key.name == 'down' and swi_cl_smenu.value == 2 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_smenu.value == 2 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_popup = vb.views[ 'csgr_popup' ]
    if ( key.name == 'down' and swi_cl_smenu.value == 3 ) then
      vb_popup.value = math.min( #vb_popup.items , vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_smenu.value == 3 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_popup = vb.views[ 'ctr_popup' ]
    if ( key.name == 'down' and swi_cl_smenu.value == 4 ) then
      vb_popup.value = math.min( #vb_popup.items,vb_popup.value + 1 )
    elseif ( key.name == 'up' and swi_cl_smenu.value == 4 ) then
      vb_popup.value = math.max( 1 , vb_popup.value - 1 )
    end
    ----
    local vb_switch = vb.views[ 'tls_switch_cl' ]
    if ( key.name == 'right' and swi_cl_hmenu.value == 4 and swi_cl_tmenu.value == 2 ) then
      vb_switch.value = math.min( #vb_switch.items , vb_switch.value + 1 )
    elseif ( key.name == 'left' and swi_cl_hmenu.value == 4 and swi_cl_tmenu.value == 2 ) then
      vb_switch.value = math.max( 1 , vb_switch.value - 1)
    end
  end
  
  dialog = renoise.app():show_custom_dialog ( ' '.. tool_name .. '  v' .. tool_version .. '     by: ulneiz' , content , keyhandler  )
  renoise.app():show_status('GT16-Colors is charged... Enjoy the colors and control!')
end

  
-- Reload the script whenever this file is saved. Additionally, execute the attached function.
_AUTO_RELOAD_DEBUG = function() show_dialog() end
--_AUTO_RELOAD_DEBUG = true


-- renoise.tool().app_new_document_observable:add_notifier(function()
  -- LOG("app_new_document_observable fired...")
  -- if not vb then
    -- return
  -- end
-- end)


--------------------------------------------------------------------------------
-- MENU ENTRIES
--------------------------------------------------------------------------------
renoise.tool():add_menu_entry {
  name = 'Main Menu:Tools:'..tool_name..'... [* ALT + CTRL + G]',
  invoke = show_dialog
}

renoise.tool():add_menu_entry {
  name = 'Pattern Editor:'..tool_name..'... [* ALT + CTRL + G]',
  invoke = show_dialog
}

renoise.tool():add_menu_entry {
  name = 'Mixer:'..tool_name..'... [* ALT + CTRL + G]',
  invoke = show_dialog
}

--------------------------------------------------------------------------------
-- KEY BINDING (RECOMENDED CTRL + ALT + G)
--------------------------------------------------------------------------------
renoise.tool():add_keybinding {
  name = 'Global:Tools:' ..tool_name..'... [* ALT + CTRL + G]',
  invoke = show_dialog
}


--[[ UNICODE SYMBOLS

 ✓ ✔ ⇅ ⇆ ← → ↑ ↓ ↆ ❙❙❙ ☲ ❘❘❘ ☰ ⎓ ➤ ❤ ✦ ✉ ▬ ⚫ ◤ ◢ ◆ ┃ ℗ Ⓒ ➥ ✘ ✖ ⬒ ⬓ ▦ ⯬ ⇱ ☲K ? ⚒
 
 ≡◄ ▲ ▼  ◄ ◄◄ ►► ► ◂ ⏯ ⏵⏸⏴ ⏪ ⏩ ⏮ ⏭ ☚ ☛ ↩ ↪ ↶ ↷ 🎹 ⚒ ☠ ☢ ☣ ⚠ ☺ ⧗ 🗗 🗕 ⇱ ⇲ ☊ ↹ ♬ ⭍

 http://unicode-table.com/en/#optical-character-recognition

--]]
